"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
@replit/protocol 0.3.6"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FileAuthMethod:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FileAuthMethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FileAuthMethod.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GET: _FileAuthMethod.ValueType  # 0
    HEAD: _FileAuthMethod.ValueType  # 1
    PUT: _FileAuthMethod.ValueType  # 2
    DELETE: _FileAuthMethod.ValueType  # 3

class FileAuthMethod(_FileAuthMethod, metaclass=_FileAuthMethodEnumTypeWrapper): ...

GET: FileAuthMethod.ValueType  # 0
HEAD: FileAuthMethod.ValueType  # 1
PUT: FileAuthMethod.ValueType  # 2
DELETE: FileAuthMethod.ValueType  # 3
global___FileAuthMethod = FileAuthMethod

class _State:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_State.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Stopped: _State.ValueType  # 0
    Running: _State.ValueType  # 1

class State(_State, metaclass=_StateEnumTypeWrapper): ...

Stopped: State.ValueType  # 0
Running: State.ValueType  # 1
global___State = State

class _TokenVersion:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TokenVersionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TokenVersion.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BARE_REPL_TOKEN: _TokenVersion.ValueType  # 0
    TYPE_AWARE_TOKEN: _TokenVersion.ValueType  # 1

class TokenVersion(_TokenVersion, metaclass=_TokenVersionEnumTypeWrapper): ...

BARE_REPL_TOKEN: TokenVersion.ValueType  # 0
TYPE_AWARE_TOKEN: TokenVersion.ValueType  # 1
global___TokenVersion = TokenVersion

class _FlagClaim:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FlagClaimEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FlagClaim.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MINT_GOVAL_TOKEN: _FlagClaim.ValueType  # 0
    SIGN_INTERMEDIATE_CERT: _FlagClaim.ValueType  # 1
    IDENTITY: _FlagClaim.ValueType  # 5
    GHOSTWRITER: _FlagClaim.ValueType  # 6
    RENEW_IDENTITY: _FlagClaim.ValueType  # 7
    RENEW_KV: _FlagClaim.ValueType  # 8
    ANY_REPLID: _FlagClaim.ValueType  # 2
    ANY_USER: _FlagClaim.ValueType  # 3
    ANY_CLUSTER: _FlagClaim.ValueType  # 4

class FlagClaim(_FlagClaim, metaclass=_FlagClaimEnumTypeWrapper): ...

MINT_GOVAL_TOKEN: FlagClaim.ValueType  # 0
SIGN_INTERMEDIATE_CERT: FlagClaim.ValueType  # 1
IDENTITY: FlagClaim.ValueType  # 5
GHOSTWRITER: FlagClaim.ValueType  # 6
RENEW_IDENTITY: FlagClaim.ValueType  # 7
RENEW_KV: FlagClaim.ValueType  # 8
ANY_REPLID: FlagClaim.ValueType  # 2
ANY_USER: FlagClaim.ValueType  # 3
ANY_CLUSTER: FlagClaim.ValueType  # 4
global___FlagClaim = FlagClaim

@typing_extensions.final
class Command(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TraceInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_FIELD_NUMBER: builtins.int
    SESSION_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    TRACEINFO_FIELD_NUMBER: builtins.int
    OPENCHAN_FIELD_NUMBER: builtins.int
    OPENCHANRES_FIELD_NUMBER: builtins.int
    CLOSECHAN_FIELD_NUMBER: builtins.int
    CLOSECHANRES_FIELD_NUMBER: builtins.int
    CONTAINERSTATE_FIELD_NUMBER: builtins.int
    PORTOPEN_FIELD_NUMBER: builtins.int
    PORTCLOSE_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    PROTOCOLERROR_FIELD_NUMBER: builtins.int
    REDIRECT_FIELD_NUMBER: builtins.int
    ALWAYSON_FIELD_NUMBER: builtins.int
    RUNMAIN_FIELD_NUMBER: builtins.int
    CLEAR_FIELD_NUMBER: builtins.int
    EVAL_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    STDERR_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    RECORD_FIELD_NUMBER: builtins.int
    SANETERM_FIELD_NUMBER: builtins.int
    RESIZETERM_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    OK_FIELD_NUMBER: builtins.int
    PERSIST_FIELD_NUMBER: builtins.int
    PERSISTMIRROR_FIELD_NUMBER: builtins.int
    WRITE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    MOVE_FIELD_NUMBER: builtins.int
    TRYREMOVE_FIELD_NUMBER: builtins.int
    MKDIR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    STATRES_FIELD_NUMBER: builtins.int
    TRANSFERSTART_FIELD_NUMBER: builtins.int
    TRANSFERCHUNK_FIELD_NUMBER: builtins.int
    TRANSFERCOMPLETE_FIELD_NUMBER: builtins.int
    TRANSFERCANCEL_FIELD_NUMBER: builtins.int
    TRANSFER_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    READDIR_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    CHECKCHANGES_FIELD_NUMBER: builtins.int
    CHANGEDFILES_FIELD_NUMBER: builtins.int
    LINTRESULTS_FIELD_NUMBER: builtins.int
    RUNCONTAINEDTEST_FIELD_NUMBER: builtins.int
    TESTRESULT_FIELD_NUMBER: builtins.int
    DEBUGGERSTART_FIELD_NUMBER: builtins.int
    DEBUGGERSTEP_FIELD_NUMBER: builtins.int
    DEBUGGERSTATUS_FIELD_NUMBER: builtins.int
    ENSUREPACKAGES_FIELD_NUMBER: builtins.int
    PING_FIELD_NUMBER: builtins.int
    PONG_FIELD_NUMBER: builtins.int
    HELLO_FIELD_NUMBER: builtins.int
    GOODBYE_FIELD_NUMBER: builtins.int
    PROXYGOINGAWAY_FIELD_NUMBER: builtins.int
    HINT_FIELD_NUMBER: builtins.int
    CONNECT_FIELD_NUMBER: builtins.int
    SEND_FIELD_NUMBER: builtins.int
    RECV_FIELD_NUMBER: builtins.int
    DISCONNECT_FIELD_NUMBER: builtins.int
    FILEAUTHREQ_FIELD_NUMBER: builtins.int
    FILEAUTHRES_FIELD_NUMBER: builtins.int
    MUTLIFILEAUTHRES_FIELD_NUMBER: builtins.int
    LISTOBJECTS_FIELD_NUMBER: builtins.int
    LISTOBJECTSRESP_FIELD_NUMBER: builtins.int
    OT_FIELD_NUMBER: builtins.int
    OTSTATUS_FIELD_NUMBER: builtins.int
    OTLINKFILE_FIELD_NUMBER: builtins.int
    OTLINKFILERESPONSE_FIELD_NUMBER: builtins.int
    OTNEWCURSOR_FIELD_NUMBER: builtins.int
    OTDELETECURSOR_FIELD_NUMBER: builtins.int
    OTFETCHREQUEST_FIELD_NUMBER: builtins.int
    OTFETCHRESPONSE_FIELD_NUMBER: builtins.int
    OTTRANSFORMSELECTIONREQUEST_FIELD_NUMBER: builtins.int
    OTTRANSFORMSELECTIONRESPONSE_FIELD_NUMBER: builtins.int
    FLUSH_FIELD_NUMBER: builtins.int
    DEBUG_FIELD_NUMBER: builtins.int
    STARTVCR_FIELD_NUMBER: builtins.int
    READVCR_FIELD_NUMBER: builtins.int
    VCRLOG_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    EXECINFO_FIELD_NUMBER: builtins.int
    SUBSCRIBEFILE_FIELD_NUMBER: builtins.int
    FILEEVENT_FIELD_NUMBER: builtins.int
    ROSTER_FIELD_NUMBER: builtins.int
    JOIN_FIELD_NUMBER: builtins.int
    PART_FIELD_NUMBER: builtins.int
    OPENFILE_FIELD_NUMBER: builtins.int
    FILEOPENED_FIELD_NUMBER: builtins.int
    FOLLOWUSER_FIELD_NUMBER: builtins.int
    UNFOLLOWUSER_FIELD_NUMBER: builtins.int
    UPDATESESSIONTIMESTAMP_FIELD_NUMBER: builtins.int
    SESSIONTIMESTAMPUPDATED_FIELD_NUMBER: builtins.int
    EXEC_FIELD_NUMBER: builtins.int
    PACKAGESEARCH_FIELD_NUMBER: builtins.int
    PACKAGESEARCHRESP_FIELD_NUMBER: builtins.int
    PACKAGEINFO_FIELD_NUMBER: builtins.int
    PACKAGEINFORESP_FIELD_NUMBER: builtins.int
    PACKAGEADD_FIELD_NUMBER: builtins.int
    PACKAGEREMOVE_FIELD_NUMBER: builtins.int
    PACKAGEINSTALL_FIELD_NUMBER: builtins.int
    PACKAGELISTSPECFILE_FIELD_NUMBER: builtins.int
    PACKAGELISTSPECFILERESP_FIELD_NUMBER: builtins.int
    PACKAGECACHESAVE_FIELD_NUMBER: builtins.int
    CHATMESSAGE_FIELD_NUMBER: builtins.int
    CHATTYPING_FIELD_NUMBER: builtins.int
    CHATSCROLLBACK_FIELD_NUMBER: builtins.int
    FSSNAPSHOT_FIELD_NUMBER: builtins.int
    FSSNAPSHOTEVENT_FIELD_NUMBER: builtins.int
    FSTAKELOCK_FIELD_NUMBER: builtins.int
    FSRELEASELOCK_FIELD_NUMBER: builtins.int
    HASCAP_FIELD_NUMBER: builtins.int
    SNAPSHOTEVENT_FIELD_NUMBER: builtins.int
    NONINTERACTIVEFSCHANGEEVENT_FIELD_NUMBER: builtins.int
    PID1CONFIG_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    BOOTSTATUS_FIELD_NUMBER: builtins.int
    READMETAREQUEST_FIELD_NUMBER: builtins.int
    READMETARESPONSE_FIELD_NUMBER: builtins.int
    WRITEMETAREQUEST_FIELD_NUMBER: builtins.int
    WRITEMETARESPONSE_FIELD_NUMBER: builtins.int
    APPENDMETAREQUEST_FIELD_NUMBER: builtins.int
    APPENDMETARESPONSE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    PPROFREQUEST_FIELD_NUMBER: builtins.int
    PPROFRESPONSE_FIELD_NUMBER: builtins.int
    AUDIO2_FIELD_NUMBER: builtins.int
    PTYCONFIG_FIELD_NUMBER: builtins.int
    DEBUGMAIN_FIELD_NUMBER: builtins.int
    DEBUGSTATE_FIELD_NUMBER: builtins.int
    DEBUGMAINREPLY_FIELD_NUMBER: builtins.int
    DEBUGINPUT_FIELD_NUMBER: builtins.int
    DEBUGOUTPUT_FIELD_NUMBER: builtins.int
    DEBUGSTOP_FIELD_NUMBER: builtins.int
    DEBUGLEAVE_FIELD_NUMBER: builtins.int
    DEBUGSESSIONS_FIELD_NUMBER: builtins.int
    DEBUGADDBREAKPOINTREQUEST_FIELD_NUMBER: builtins.int
    DEBUGUPDATEBREAKPOINTREQUEST_FIELD_NUMBER: builtins.int
    DEBUGREMOVEBREAKPOINTREQUEST_FIELD_NUMBER: builtins.int
    DEBUGBREAKPOINTEVENT_FIELD_NUMBER: builtins.int
    DOTREPLITGETREQUEST_FIELD_NUMBER: builtins.int
    DOTREPLITGETRESPONSE_FIELD_NUMBER: builtins.int
    RUNCONFIGGETREQUEST_FIELD_NUMBER: builtins.int
    RUNCONFIGGETRESPONSE_FIELD_NUMBER: builtins.int
    DOTREPLITUPDATEREQUEST_FIELD_NUMBER: builtins.int
    DOTREPLITUPDATERESPONSE_FIELD_NUMBER: builtins.int
    STARTLSP_FIELD_NUMBER: builtins.int
    FIREWALLDENIED_FIELD_NUMBER: builtins.int
    NIXPACKAGEADDREQUEST_FIELD_NUMBER: builtins.int
    NIXPACKAGEADDRESPONSE_FIELD_NUMBER: builtins.int
    NIXPACKAGEREMOVEREQUEST_FIELD_NUMBER: builtins.int
    NIXPACKAGEREMOVERESPONSE_FIELD_NUMBER: builtins.int
    NIXPACKAGELISTREQUEST_FIELD_NUMBER: builtins.int
    NIXPACKAGELISTRESPONSE_FIELD_NUMBER: builtins.int
    NIXCHANNELSREQUEST_FIELD_NUMBER: builtins.int
    NIXCHANNELSRESPONSE_FIELD_NUMBER: builtins.int
    NIXCHANNELLATESTSTABLEREQUEST_FIELD_NUMBER: builtins.int
    NIXCHANNELLATESTSTABLERESPONSE_FIELD_NUMBER: builtins.int
    NIXPACKAGESEARCHREQUEST_FIELD_NUMBER: builtins.int
    NIXPACKAGESEARCHRESPONSE_FIELD_NUMBER: builtins.int
    USEREVENT_FIELD_NUMBER: builtins.int
    REPLSPACEAPIOPENFILE_FIELD_NUMBER: builtins.int
    REPLSPACEAPICLOSEFILE_FIELD_NUMBER: builtins.int
    REPLSPACEAPIGETGITHUBTOKEN_FIELD_NUMBER: builtins.int
    REPLSPACEAPIGITHUBTOKEN_FIELD_NUMBER: builtins.int
    FOCUSED_FIELD_NUMBER: builtins.int
    NIXMODULESGETREQUEST_FIELD_NUMBER: builtins.int
    NIXMODULESGETRESPONSE_FIELD_NUMBER: builtins.int
    NIXMODULESCHANGED_FIELD_NUMBER: builtins.int
    NIXMODULESBUILDREQUEST_FIELD_NUMBER: builtins.int
    PACKAGESETPACKAGERREQUEST_FIELD_NUMBER: builtins.int
    PACKAGESETPACKAGERRESP_FIELD_NUMBER: builtins.int
    TOOLCHAINGETREQUEST_FIELD_NUMBER: builtins.int
    TOOLCHAINGETRESPONSE_FIELD_NUMBER: builtins.int
    TOOLCHAINCHANGED_FIELD_NUMBER: builtins.int
    channel: builtins.int
    session: builtins.int
    ref: builtins.str
    @property
    def traceInfo(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def openChan(self) -> global___OpenChannel: ...
    @property
    def openChanRes(self) -> global___OpenChannelRes: ...
    @property
    def closeChan(self) -> global___CloseChannel: ...
    @property
    def closeChanRes(self) -> global___CloseChannelRes: ...
    @property
    def containerState(self) -> global___ContainerState: ...
    @property
    def portOpen(self) -> global___PortOpen: ...
    @property
    def portClose(self) -> global___PortClose: ...
    @property
    def toast(self) -> global___Toast: ...
    @property
    def protocolError(self) -> global___ProtocolError: ...
    @property
    def redirect(self) -> global___Redirect: ...
    @property
    def alwaysOn(self) -> global___AlwaysOn: ...
    @property
    def runMain(self) -> global___RunMain: ...
    @property
    def clear(self) -> global___Clear: ...
    eval: builtins.str
    result: builtins.str
    input: builtins.str
    output: builtins.str
    error: builtins.str
    stderr: builtins.str
    log: builtins.str
    record: builtins.str
    @property
    def saneTerm(self) -> global___SaneTerm: ...
    @property
    def resizeTerm(self) -> global___ResizeTerm: ...
    state: global___State.ValueType
    @property
    def ok(self) -> global___OK: ...
    @property
    def persist(self) -> global___File: ...
    @property
    def persistMirror(self) -> global___File: ...
    @property
    def write(self) -> global___File: ...
    @property
    def remove(self) -> global___File: ...
    @property
    def move(self) -> global___Move: ...
    @property
    def tryRemove(self) -> global___File: ...
    @property
    def mkdir(self) -> global___File: ...
    @property
    def stat(self) -> global___File: ...
    @property
    def statRes(self) -> global___StatResult: ...
    @property
    def transferStart(self) -> global___TransferStart: ...
    @property
    def transferChunk(self) -> global___TransferChunk: ...
    @property
    def transferComplete(self) -> global___TransferComplete: ...
    @property
    def transferCancel(self) -> global___Transfer: ...
    @property
    def transfer(self) -> global___Transfer: ...
    @property
    def read(self) -> global___File: ...
    @property
    def readdir(self) -> global___File: ...
    @property
    def files(self) -> global___Files: ...
    @property
    def file(self) -> global___File: ...
    @property
    def checkChanges(self) -> global___CheckChanges: ...
    @property
    def changedFiles(self) -> global___Files: ...
    @property
    def lintResults(self) -> global___LintResults: ...
    @property
    def runContainedTest(self) -> global___ContainedTest: ...
    @property
    def testResult(self) -> global___TestResult: ...
    debuggerStart: builtins.str
    @property
    def debuggerStep(self) -> global___RunMain: ...
    @property
    def debuggerStatus(self) -> global___DebugStatus: ...
    @property
    def ensurePackages(self) -> global___EnsurePackages: ...
    @property
    def ping(self) -> global___Ping: ...
    @property
    def pong(self) -> global___Pong: ...
    @property
    def hello(self) -> global___Hello: ...
    @property
    def goodbye(self) -> global___Goodbye: ...
    @property
    def proxyGoingAway(self) -> global___ProxyGoingAway: ...
    @property
    def hint(self) -> global___Hint: ...
    @property
    def connect(self) -> global___Connect: ...
    @property
    def send(self) -> global___Send: ...
    @property
    def recv(self) -> global___Recv: ...
    @property
    def disconnect(self) -> global___Disconnect: ...
    @property
    def fileAuthReq(self) -> global___FileAuthReq: ...
    @property
    def fileAuthRes(self) -> global___FileAuthRes: ...
    @property
    def mutliFileAuthRes(self) -> global___MultiFileAuthRes: ...
    @property
    def listObjects(self) -> global___ListObjects: ...
    @property
    def listObjectsResp(self) -> global___ListObjectsResp: ...
    @property
    def ot(self) -> global___OTPacket: ...
    @property
    def otstatus(self) -> global___OTStatus: ...
    @property
    def otLinkFile(self) -> global___OTLinkFile: ...
    @property
    def otLinkFileResponse(self) -> global___OTLinkFileResponse: ...
    @property
    def otNewCursor(self) -> global___OTCursor: ...
    @property
    def otDeleteCursor(self) -> global___OTCursor: ...
    @property
    def otFetchRequest(self) -> global___OTFetchRequest: ...
    @property
    def otFetchResponse(self) -> global___OTFetchResponse: ...
    @property
    def otTransformSelectionRequest(self) -> global___OTTransformSelectionRequest: ...
    @property
    def otTransformSelectionResponse(self) -> global___OTTransformSelectionResponse: ...
    @property
    def flush(self) -> global___Flush: ...
    @property
    def debug(self) -> global___Debug: ...
    @property
    def startVCR(self) -> global___StartVCR: ...
    @property
    def readVCR(self) -> global___ReadVCR: ...
    @property
    def VCRLog(self) -> global___VCRLog: ...
    @property
    def auth(self) -> global___Auth: ...
    @property
    def execInfo(self) -> global___ExecInfo: ...
    @property
    def subscribeFile(self) -> global___SubscribeFile: ...
    @property
    def fileEvent(self) -> global___FileEvent: ...
    @property
    def roster(self) -> global___Roster: ...
    @property
    def join(self) -> global___User: ...
    @property
    def part(self) -> global___User: ...
    @property
    def openFile(self) -> global___OpenFile: ...
    @property
    def fileOpened(self) -> global___FileOpened: ...
    @property
    def followUser(self) -> global___FollowUser: ...
    @property
    def unfollowUser(self) -> global___UnfollowUser: ...
    @property
    def updateSessionTimestamp(self) -> global___UpdateSessionTimestamp: ...
    @property
    def sessionTimestampUpdated(self) -> global___SessionTimestampUpdated: ...
    @property
    def exec(self) -> global___Exec: ...
    @property
    def packageSearch(self) -> global___PackageSearch: ...
    @property
    def packageSearchResp(self) -> global___PackageSearchResp: ...
    @property
    def packageInfo(self) -> global___PackageInfo: ...
    @property
    def packageInfoResp(self) -> global___PackageInfoResp: ...
    @property
    def packageAdd(self) -> global___PackageAdd: ...
    @property
    def packageRemove(self) -> global___PackageRemove: ...
    @property
    def packageInstall(self) -> global___PackageInstall: ...
    @property
    def packageListSpecfile(self) -> global___PackageListSpecfile: ...
    @property
    def packageListSpecfileResp(self) -> global___PackageListSpecfileResp: ...
    @property
    def packageCacheSave(self) -> global___PackageCacheSave: ...
    @property
    def chatMessage(self) -> global___ChatMessage: ...
    @property
    def chatTyping(self) -> global___ChatTyping: ...
    @property
    def chatScrollback(self) -> global___ChatScrollback: ...
    @property
    def fsSnapshot(self) -> global___FSSnapshot: ...
    @property
    def fsSnapshotEvent(self) -> global___FSSnapshotEvent: ...
    @property
    def fsTakeLock(self) -> global___FSLock: ...
    @property
    def fsReleaseLock(self) -> global___FSLock: ...
    hasCap: builtins.bool
    @property
    def snapshotEvent(self) -> global___SnapshotEvent: ...
    NoninteractiveFSChangeEvent: builtins.bool
    @property
    def pid1Config(self) -> global___Pid1Config: ...
    @property
    def metrics(self) -> global___Metrics: ...
    @property
    def bootStatus(self) -> global___BootStatus: ...
    @property
    def readMetaRequest(self) -> global___ReadMetaRequest: ...
    @property
    def readMetaResponse(self) -> global___ReadMetaResponse: ...
    @property
    def writeMetaRequest(self) -> global___WriteMetaRequest: ...
    @property
    def writeMetaResponse(self) -> global___WriteMetaResponse: ...
    @property
    def appendMetaRequest(self) -> global___AppendMetaRequest: ...
    @property
    def appendMetaResponse(self) -> global___AppendMetaResponse: ...
    @property
    def audio(self) -> global___Audio: ...
    @property
    def pprofRequest(self) -> global___PprofRequest: ...
    @property
    def pprofResponse(self) -> global___PprofResponse: ...
    @property
    def audio2(self) -> global___Audio2: ...
    @property
    def PTYConfig(self) -> global___PTYConfig: ...
    @property
    def debugMain(self) -> global___DebugMain: ...
    @property
    def debugState(self) -> global___DebugState: ...
    @property
    def debugMainReply(self) -> global___DebugMainReply: ...
    @property
    def debugInput(self) -> global___DebugInput: ...
    @property
    def debugOutput(self) -> global___DebugOutput: ...
    @property
    def debugStop(self) -> global___DebugStop: ...
    @property
    def debugLeave(self) -> global___DebugLeave: ...
    @property
    def debugSessions(self) -> global___DebugSessions: ...
    @property
    def debugAddBreakpointRequest(self) -> global___DebugAddBreakpointRequest: ...
    @property
    def debugUpdateBreakpointRequest(self) -> global___DebugUpdateBreakpointRequest: ...
    @property
    def debugRemoveBreakpointRequest(self) -> global___DebugRemoveBreakpointRequest: ...
    @property
    def debugBreakpointEvent(self) -> global___DebugBreakpointEvent: ...
    @property
    def dotReplitGetRequest(self) -> global___DotReplitGetRequest: ...
    @property
    def dotReplitGetResponse(self) -> global___DotReplitGetResponse: ...
    @property
    def runConfigGetRequest(self) -> global___RunConfigGetRequest: ...
    @property
    def runConfigGetResponse(self) -> global___RunConfigGetResponse: ...
    @property
    def dotReplitUpdateRequest(self) -> global___DotReplitUpdateRequest: ...
    @property
    def dotReplitUpdateResponse(self) -> global___DotReplitUpdateResponse: ...
    @property
    def startLSP(self) -> global___StartLSP: ...
    @property
    def firewallDenied(self) -> global___FirewallDenied: ...
    @property
    def nixPackageAddRequest(self) -> global___NixPackageAddRequest: ...
    @property
    def nixPackageAddResponse(self) -> global___NixPackageAddResponse: ...
    @property
    def nixPackageRemoveRequest(self) -> global___NixPackageRemoveRequest: ...
    @property
    def nixPackageRemoveResponse(self) -> global___NixPackageRemoveResponse: ...
    @property
    def nixPackageListRequest(self) -> global___NixPackageListRequest: ...
    @property
    def nixPackageListResponse(self) -> global___NixPackageListResponse: ...
    @property
    def nixChannelsRequest(self) -> global___NixChannelsRequest: ...
    @property
    def nixChannelsResponse(self) -> global___NixChannelsResponse: ...
    @property
    def nixChannelLatestStableRequest(self) -> global___NixChannelLatestStableRequest: ...
    @property
    def nixChannelLatestStableResponse(self) -> global___NixChannelLatestStableResponse: ...
    @property
    def nixPackageSearchRequest(self) -> global___NixPackageSearchRequest: ...
    @property
    def nixPackageSearchResponse(self) -> global___NixPackageSearchResponse: ...
    @property
    def userEvent(self) -> global___UserEvent: ...
    @property
    def replspaceApiOpenFile(self) -> global___ReplspaceApiOpenFile: ...
    @property
    def replspaceApiCloseFile(self) -> global___ReplspaceApiCloseFile: ...
    @property
    def replspaceApiGetGitHubToken(self) -> global___ReplspaceApiGetGitHubToken: ...
    @property
    def replspaceApiGitHubToken(self) -> global___ReplspaceApiGitHubToken: ...
    @property
    def focused(self) -> global___Focused: ...
    @property
    def nixModulesGetRequest(self) -> global___NixModulesGetRequest: ...
    @property
    def nixModulesGetResponse(self) -> global___NixModulesGetResponse: ...
    @property
    def nixModulesChanged(self) -> global___NixModulesChanged: ...
    @property
    def nixModulesBuildRequest(self) -> global___NixModulesBuildRequest: ...
    @property
    def packageSetPackagerRequest(self) -> global___PackageSetPackagerRequest: ...
    @property
    def packageSetPackagerResp(self) -> global___PackageSetPackagerResponse: ...
    @property
    def toolchainGetRequest(self) -> global___ToolchainGetRequest: ...
    @property
    def toolchainGetResponse(self) -> global___ToolchainGetResponse: ...
    @property
    def toolchainChanged(self) -> global___ToolchainChanged: ...
    def __init__(
        self,
        *,
        channel: builtins.int = ...,
        session: builtins.int = ...,
        ref: builtins.str = ...,
        traceInfo: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        openChan: global___OpenChannel | None = ...,
        openChanRes: global___OpenChannelRes | None = ...,
        closeChan: global___CloseChannel | None = ...,
        closeChanRes: global___CloseChannelRes | None = ...,
        containerState: global___ContainerState | None = ...,
        portOpen: global___PortOpen | None = ...,
        portClose: global___PortClose | None = ...,
        toast: global___Toast | None = ...,
        protocolError: global___ProtocolError | None = ...,
        redirect: global___Redirect | None = ...,
        alwaysOn: global___AlwaysOn | None = ...,
        runMain: global___RunMain | None = ...,
        clear: global___Clear | None = ...,
        eval: builtins.str = ...,
        result: builtins.str = ...,
        input: builtins.str = ...,
        output: builtins.str = ...,
        error: builtins.str = ...,
        stderr: builtins.str = ...,
        log: builtins.str = ...,
        record: builtins.str = ...,
        saneTerm: global___SaneTerm | None = ...,
        resizeTerm: global___ResizeTerm | None = ...,
        state: global___State.ValueType = ...,
        ok: global___OK | None = ...,
        persist: global___File | None = ...,
        persistMirror: global___File | None = ...,
        write: global___File | None = ...,
        remove: global___File | None = ...,
        move: global___Move | None = ...,
        tryRemove: global___File | None = ...,
        mkdir: global___File | None = ...,
        stat: global___File | None = ...,
        statRes: global___StatResult | None = ...,
        transferStart: global___TransferStart | None = ...,
        transferChunk: global___TransferChunk | None = ...,
        transferComplete: global___TransferComplete | None = ...,
        transferCancel: global___Transfer | None = ...,
        transfer: global___Transfer | None = ...,
        read: global___File | None = ...,
        readdir: global___File | None = ...,
        files: global___Files | None = ...,
        file: global___File | None = ...,
        checkChanges: global___CheckChanges | None = ...,
        changedFiles: global___Files | None = ...,
        lintResults: global___LintResults | None = ...,
        runContainedTest: global___ContainedTest | None = ...,
        testResult: global___TestResult | None = ...,
        debuggerStart: builtins.str = ...,
        debuggerStep: global___RunMain | None = ...,
        debuggerStatus: global___DebugStatus | None = ...,
        ensurePackages: global___EnsurePackages | None = ...,
        ping: global___Ping | None = ...,
        pong: global___Pong | None = ...,
        hello: global___Hello | None = ...,
        goodbye: global___Goodbye | None = ...,
        proxyGoingAway: global___ProxyGoingAway | None = ...,
        hint: global___Hint | None = ...,
        connect: global___Connect | None = ...,
        send: global___Send | None = ...,
        recv: global___Recv | None = ...,
        disconnect: global___Disconnect | None = ...,
        fileAuthReq: global___FileAuthReq | None = ...,
        fileAuthRes: global___FileAuthRes | None = ...,
        mutliFileAuthRes: global___MultiFileAuthRes | None = ...,
        listObjects: global___ListObjects | None = ...,
        listObjectsResp: global___ListObjectsResp | None = ...,
        ot: global___OTPacket | None = ...,
        otstatus: global___OTStatus | None = ...,
        otLinkFile: global___OTLinkFile | None = ...,
        otLinkFileResponse: global___OTLinkFileResponse | None = ...,
        otNewCursor: global___OTCursor | None = ...,
        otDeleteCursor: global___OTCursor | None = ...,
        otFetchRequest: global___OTFetchRequest | None = ...,
        otFetchResponse: global___OTFetchResponse | None = ...,
        otTransformSelectionRequest: global___OTTransformSelectionRequest | None = ...,
        otTransformSelectionResponse: global___OTTransformSelectionResponse | None = ...,
        flush: global___Flush | None = ...,
        debug: global___Debug | None = ...,
        startVCR: global___StartVCR | None = ...,
        readVCR: global___ReadVCR | None = ...,
        VCRLog: global___VCRLog | None = ...,
        auth: global___Auth | None = ...,
        execInfo: global___ExecInfo | None = ...,
        subscribeFile: global___SubscribeFile | None = ...,
        fileEvent: global___FileEvent | None = ...,
        roster: global___Roster | None = ...,
        join: global___User | None = ...,
        part: global___User | None = ...,
        openFile: global___OpenFile | None = ...,
        fileOpened: global___FileOpened | None = ...,
        followUser: global___FollowUser | None = ...,
        unfollowUser: global___UnfollowUser | None = ...,
        updateSessionTimestamp: global___UpdateSessionTimestamp | None = ...,
        sessionTimestampUpdated: global___SessionTimestampUpdated | None = ...,
        exec: global___Exec | None = ...,
        packageSearch: global___PackageSearch | None = ...,
        packageSearchResp: global___PackageSearchResp | None = ...,
        packageInfo: global___PackageInfo | None = ...,
        packageInfoResp: global___PackageInfoResp | None = ...,
        packageAdd: global___PackageAdd | None = ...,
        packageRemove: global___PackageRemove | None = ...,
        packageInstall: global___PackageInstall | None = ...,
        packageListSpecfile: global___PackageListSpecfile | None = ...,
        packageListSpecfileResp: global___PackageListSpecfileResp | None = ...,
        packageCacheSave: global___PackageCacheSave | None = ...,
        chatMessage: global___ChatMessage | None = ...,
        chatTyping: global___ChatTyping | None = ...,
        chatScrollback: global___ChatScrollback | None = ...,
        fsSnapshot: global___FSSnapshot | None = ...,
        fsSnapshotEvent: global___FSSnapshotEvent | None = ...,
        fsTakeLock: global___FSLock | None = ...,
        fsReleaseLock: global___FSLock | None = ...,
        hasCap: builtins.bool = ...,
        snapshotEvent: global___SnapshotEvent | None = ...,
        NoninteractiveFSChangeEvent: builtins.bool = ...,
        pid1Config: global___Pid1Config | None = ...,
        metrics: global___Metrics | None = ...,
        bootStatus: global___BootStatus | None = ...,
        readMetaRequest: global___ReadMetaRequest | None = ...,
        readMetaResponse: global___ReadMetaResponse | None = ...,
        writeMetaRequest: global___WriteMetaRequest | None = ...,
        writeMetaResponse: global___WriteMetaResponse | None = ...,
        appendMetaRequest: global___AppendMetaRequest | None = ...,
        appendMetaResponse: global___AppendMetaResponse | None = ...,
        audio: global___Audio | None = ...,
        pprofRequest: global___PprofRequest | None = ...,
        pprofResponse: global___PprofResponse | None = ...,
        audio2: global___Audio2 | None = ...,
        PTYConfig: global___PTYConfig | None = ...,
        debugMain: global___DebugMain | None = ...,
        debugState: global___DebugState | None = ...,
        debugMainReply: global___DebugMainReply | None = ...,
        debugInput: global___DebugInput | None = ...,
        debugOutput: global___DebugOutput | None = ...,
        debugStop: global___DebugStop | None = ...,
        debugLeave: global___DebugLeave | None = ...,
        debugSessions: global___DebugSessions | None = ...,
        debugAddBreakpointRequest: global___DebugAddBreakpointRequest | None = ...,
        debugUpdateBreakpointRequest: global___DebugUpdateBreakpointRequest | None = ...,
        debugRemoveBreakpointRequest: global___DebugRemoveBreakpointRequest | None = ...,
        debugBreakpointEvent: global___DebugBreakpointEvent | None = ...,
        dotReplitGetRequest: global___DotReplitGetRequest | None = ...,
        dotReplitGetResponse: global___DotReplitGetResponse | None = ...,
        runConfigGetRequest: global___RunConfigGetRequest | None = ...,
        runConfigGetResponse: global___RunConfigGetResponse | None = ...,
        dotReplitUpdateRequest: global___DotReplitUpdateRequest | None = ...,
        dotReplitUpdateResponse: global___DotReplitUpdateResponse | None = ...,
        startLSP: global___StartLSP | None = ...,
        firewallDenied: global___FirewallDenied | None = ...,
        nixPackageAddRequest: global___NixPackageAddRequest | None = ...,
        nixPackageAddResponse: global___NixPackageAddResponse | None = ...,
        nixPackageRemoveRequest: global___NixPackageRemoveRequest | None = ...,
        nixPackageRemoveResponse: global___NixPackageRemoveResponse | None = ...,
        nixPackageListRequest: global___NixPackageListRequest | None = ...,
        nixPackageListResponse: global___NixPackageListResponse | None = ...,
        nixChannelsRequest: global___NixChannelsRequest | None = ...,
        nixChannelsResponse: global___NixChannelsResponse | None = ...,
        nixChannelLatestStableRequest: global___NixChannelLatestStableRequest | None = ...,
        nixChannelLatestStableResponse: global___NixChannelLatestStableResponse | None = ...,
        nixPackageSearchRequest: global___NixPackageSearchRequest | None = ...,
        nixPackageSearchResponse: global___NixPackageSearchResponse | None = ...,
        userEvent: global___UserEvent | None = ...,
        replspaceApiOpenFile: global___ReplspaceApiOpenFile | None = ...,
        replspaceApiCloseFile: global___ReplspaceApiCloseFile | None = ...,
        replspaceApiGetGitHubToken: global___ReplspaceApiGetGitHubToken | None = ...,
        replspaceApiGitHubToken: global___ReplspaceApiGitHubToken | None = ...,
        focused: global___Focused | None = ...,
        nixModulesGetRequest: global___NixModulesGetRequest | None = ...,
        nixModulesGetResponse: global___NixModulesGetResponse | None = ...,
        nixModulesChanged: global___NixModulesChanged | None = ...,
        nixModulesBuildRequest: global___NixModulesBuildRequest | None = ...,
        packageSetPackagerRequest: global___PackageSetPackagerRequest | None = ...,
        packageSetPackagerResp: global___PackageSetPackagerResponse | None = ...,
        toolchainGetRequest: global___ToolchainGetRequest | None = ...,
        toolchainGetResponse: global___ToolchainGetResponse | None = ...,
        toolchainChanged: global___ToolchainChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["NoninteractiveFSChangeEvent", b"NoninteractiveFSChangeEvent", "PTYConfig", b"PTYConfig", "VCRLog", b"VCRLog", "alwaysOn", b"alwaysOn", "appendMetaRequest", b"appendMetaRequest", "appendMetaResponse", b"appendMetaResponse", "audio", b"audio", "audio2", b"audio2", "auth", b"auth", "body", b"body", "bootStatus", b"bootStatus", "changedFiles", b"changedFiles", "chatMessage", b"chatMessage", "chatScrollback", b"chatScrollback", "chatTyping", b"chatTyping", "checkChanges", b"checkChanges", "clear", b"clear", "closeChan", b"closeChan", "closeChanRes", b"closeChanRes", "connect", b"connect", "containerState", b"containerState", "debug", b"debug", "debugAddBreakpointRequest", b"debugAddBreakpointRequest", "debugBreakpointEvent", b"debugBreakpointEvent", "debugInput", b"debugInput", "debugLeave", b"debugLeave", "debugMain", b"debugMain", "debugMainReply", b"debugMainReply", "debugOutput", b"debugOutput", "debugRemoveBreakpointRequest", b"debugRemoveBreakpointRequest", "debugSessions", b"debugSessions", "debugState", b"debugState", "debugStop", b"debugStop", "debugUpdateBreakpointRequest", b"debugUpdateBreakpointRequest", "debuggerStart", b"debuggerStart", "debuggerStatus", b"debuggerStatus", "debuggerStep", b"debuggerStep", "disconnect", b"disconnect", "dotReplitGetRequest", b"dotReplitGetRequest", "dotReplitGetResponse", b"dotReplitGetResponse", "dotReplitUpdateRequest", b"dotReplitUpdateRequest", "dotReplitUpdateResponse", b"dotReplitUpdateResponse", "ensurePackages", b"ensurePackages", "error", b"error", "eval", b"eval", "exec", b"exec", "execInfo", b"execInfo", "file", b"file", "fileAuthReq", b"fileAuthReq", "fileAuthRes", b"fileAuthRes", "fileEvent", b"fileEvent", "fileOpened", b"fileOpened", "files", b"files", "firewallDenied", b"firewallDenied", "flush", b"flush", "focused", b"focused", "followUser", b"followUser", "fsReleaseLock", b"fsReleaseLock", "fsSnapshot", b"fsSnapshot", "fsSnapshotEvent", b"fsSnapshotEvent", "fsTakeLock", b"fsTakeLock", "goodbye", b"goodbye", "hasCap", b"hasCap", "hello", b"hello", "hint", b"hint", "input", b"input", "join", b"join", "lintResults", b"lintResults", "listObjects", b"listObjects", "listObjectsResp", b"listObjectsResp", "log", b"log", "metrics", b"metrics", "mkdir", b"mkdir", "move", b"move", "mutliFileAuthRes", b"mutliFileAuthRes", "nixChannelLatestStableRequest", b"nixChannelLatestStableRequest", "nixChannelLatestStableResponse", b"nixChannelLatestStableResponse", "nixChannelsRequest", b"nixChannelsRequest", "nixChannelsResponse", b"nixChannelsResponse", "nixModulesBuildRequest", b"nixModulesBuildRequest", "nixModulesChanged", b"nixModulesChanged", "nixModulesGetRequest", b"nixModulesGetRequest", "nixModulesGetResponse", b"nixModulesGetResponse", "nixPackageAddRequest", b"nixPackageAddRequest", "nixPackageAddResponse", b"nixPackageAddResponse", "nixPackageListRequest", b"nixPackageListRequest", "nixPackageListResponse", b"nixPackageListResponse", "nixPackageRemoveRequest", b"nixPackageRemoveRequest", "nixPackageRemoveResponse", b"nixPackageRemoveResponse", "nixPackageSearchRequest", b"nixPackageSearchRequest", "nixPackageSearchResponse", b"nixPackageSearchResponse", "ok", b"ok", "openChan", b"openChan", "openChanRes", b"openChanRes", "openFile", b"openFile", "ot", b"ot", "otDeleteCursor", b"otDeleteCursor", "otFetchRequest", b"otFetchRequest", "otFetchResponse", b"otFetchResponse", "otLinkFile", b"otLinkFile", "otLinkFileResponse", b"otLinkFileResponse", "otNewCursor", b"otNewCursor", "otTransformSelectionRequest", b"otTransformSelectionRequest", "otTransformSelectionResponse", b"otTransformSelectionResponse", "otstatus", b"otstatus", "output", b"output", "packageAdd", b"packageAdd", "packageCacheSave", b"packageCacheSave", "packageInfo", b"packageInfo", "packageInfoResp", b"packageInfoResp", "packageInstall", b"packageInstall", "packageListSpecfile", b"packageListSpecfile", "packageListSpecfileResp", b"packageListSpecfileResp", "packageRemove", b"packageRemove", "packageSearch", b"packageSearch", "packageSearchResp", b"packageSearchResp", "packageSetPackagerRequest", b"packageSetPackagerRequest", "packageSetPackagerResp", b"packageSetPackagerResp", "part", b"part", "persist", b"persist", "persistMirror", b"persistMirror", "pid1Config", b"pid1Config", "ping", b"ping", "pong", b"pong", "portClose", b"portClose", "portOpen", b"portOpen", "pprofRequest", b"pprofRequest", "pprofResponse", b"pprofResponse", "protocolError", b"protocolError", "proxyGoingAway", b"proxyGoingAway", "read", b"read", "readMetaRequest", b"readMetaRequest", "readMetaResponse", b"readMetaResponse", "readVCR", b"readVCR", "readdir", b"readdir", "record", b"record", "recv", b"recv", "redirect", b"redirect", "remove", b"remove", "replspaceApiCloseFile", b"replspaceApiCloseFile", "replspaceApiGetGitHubToken", b"replspaceApiGetGitHubToken", "replspaceApiGitHubToken", b"replspaceApiGitHubToken", "replspaceApiOpenFile", b"replspaceApiOpenFile", "resizeTerm", b"resizeTerm", "result", b"result", "roster", b"roster", "runConfigGetRequest", b"runConfigGetRequest", "runConfigGetResponse", b"runConfigGetResponse", "runContainedTest", b"runContainedTest", "runMain", b"runMain", "saneTerm", b"saneTerm", "send", b"send", "sessionTimestampUpdated", b"sessionTimestampUpdated", "snapshotEvent", b"snapshotEvent", "startLSP", b"startLSP", "startVCR", b"startVCR", "stat", b"stat", "statRes", b"statRes", "state", b"state", "stderr", b"stderr", "subscribeFile", b"subscribeFile", "testResult", b"testResult", "toast", b"toast", "toolchainChanged", b"toolchainChanged", "toolchainGetRequest", b"toolchainGetRequest", "toolchainGetResponse", b"toolchainGetResponse", "transfer", b"transfer", "transferCancel", b"transferCancel", "transferChunk", b"transferChunk", "transferComplete", b"transferComplete", "transferStart", b"transferStart", "tryRemove", b"tryRemove", "unfollowUser", b"unfollowUser", "updateSessionTimestamp", b"updateSessionTimestamp", "userEvent", b"userEvent", "write", b"write", "writeMetaRequest", b"writeMetaRequest", "writeMetaResponse", b"writeMetaResponse"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["NoninteractiveFSChangeEvent", b"NoninteractiveFSChangeEvent", "PTYConfig", b"PTYConfig", "VCRLog", b"VCRLog", "alwaysOn", b"alwaysOn", "appendMetaRequest", b"appendMetaRequest", "appendMetaResponse", b"appendMetaResponse", "audio", b"audio", "audio2", b"audio2", "auth", b"auth", "body", b"body", "bootStatus", b"bootStatus", "changedFiles", b"changedFiles", "channel", b"channel", "chatMessage", b"chatMessage", "chatScrollback", b"chatScrollback", "chatTyping", b"chatTyping", "checkChanges", b"checkChanges", "clear", b"clear", "closeChan", b"closeChan", "closeChanRes", b"closeChanRes", "connect", b"connect", "containerState", b"containerState", "debug", b"debug", "debugAddBreakpointRequest", b"debugAddBreakpointRequest", "debugBreakpointEvent", b"debugBreakpointEvent", "debugInput", b"debugInput", "debugLeave", b"debugLeave", "debugMain", b"debugMain", "debugMainReply", b"debugMainReply", "debugOutput", b"debugOutput", "debugRemoveBreakpointRequest", b"debugRemoveBreakpointRequest", "debugSessions", b"debugSessions", "debugState", b"debugState", "debugStop", b"debugStop", "debugUpdateBreakpointRequest", b"debugUpdateBreakpointRequest", "debuggerStart", b"debuggerStart", "debuggerStatus", b"debuggerStatus", "debuggerStep", b"debuggerStep", "disconnect", b"disconnect", "dotReplitGetRequest", b"dotReplitGetRequest", "dotReplitGetResponse", b"dotReplitGetResponse", "dotReplitUpdateRequest", b"dotReplitUpdateRequest", "dotReplitUpdateResponse", b"dotReplitUpdateResponse", "ensurePackages", b"ensurePackages", "error", b"error", "eval", b"eval", "exec", b"exec", "execInfo", b"execInfo", "file", b"file", "fileAuthReq", b"fileAuthReq", "fileAuthRes", b"fileAuthRes", "fileEvent", b"fileEvent", "fileOpened", b"fileOpened", "files", b"files", "firewallDenied", b"firewallDenied", "flush", b"flush", "focused", b"focused", "followUser", b"followUser", "fsReleaseLock", b"fsReleaseLock", "fsSnapshot", b"fsSnapshot", "fsSnapshotEvent", b"fsSnapshotEvent", "fsTakeLock", b"fsTakeLock", "goodbye", b"goodbye", "hasCap", b"hasCap", "hello", b"hello", "hint", b"hint", "input", b"input", "join", b"join", "lintResults", b"lintResults", "listObjects", b"listObjects", "listObjectsResp", b"listObjectsResp", "log", b"log", "metrics", b"metrics", "mkdir", b"mkdir", "move", b"move", "mutliFileAuthRes", b"mutliFileAuthRes", "nixChannelLatestStableRequest", b"nixChannelLatestStableRequest", "nixChannelLatestStableResponse", b"nixChannelLatestStableResponse", "nixChannelsRequest", b"nixChannelsRequest", "nixChannelsResponse", b"nixChannelsResponse", "nixModulesBuildRequest", b"nixModulesBuildRequest", "nixModulesChanged", b"nixModulesChanged", "nixModulesGetRequest", b"nixModulesGetRequest", "nixModulesGetResponse", b"nixModulesGetResponse", "nixPackageAddRequest", b"nixPackageAddRequest", "nixPackageAddResponse", b"nixPackageAddResponse", "nixPackageListRequest", b"nixPackageListRequest", "nixPackageListResponse", b"nixPackageListResponse", "nixPackageRemoveRequest", b"nixPackageRemoveRequest", "nixPackageRemoveResponse", b"nixPackageRemoveResponse", "nixPackageSearchRequest", b"nixPackageSearchRequest", "nixPackageSearchResponse", b"nixPackageSearchResponse", "ok", b"ok", "openChan", b"openChan", "openChanRes", b"openChanRes", "openFile", b"openFile", "ot", b"ot", "otDeleteCursor", b"otDeleteCursor", "otFetchRequest", b"otFetchRequest", "otFetchResponse", b"otFetchResponse", "otLinkFile", b"otLinkFile", "otLinkFileResponse", b"otLinkFileResponse", "otNewCursor", b"otNewCursor", "otTransformSelectionRequest", b"otTransformSelectionRequest", "otTransformSelectionResponse", b"otTransformSelectionResponse", "otstatus", b"otstatus", "output", b"output", "packageAdd", b"packageAdd", "packageCacheSave", b"packageCacheSave", "packageInfo", b"packageInfo", "packageInfoResp", b"packageInfoResp", "packageInstall", b"packageInstall", "packageListSpecfile", b"packageListSpecfile", "packageListSpecfileResp", b"packageListSpecfileResp", "packageRemove", b"packageRemove", "packageSearch", b"packageSearch", "packageSearchResp", b"packageSearchResp", "packageSetPackagerRequest", b"packageSetPackagerRequest", "packageSetPackagerResp", b"packageSetPackagerResp", "part", b"part", "persist", b"persist", "persistMirror", b"persistMirror", "pid1Config", b"pid1Config", "ping", b"ping", "pong", b"pong", "portClose", b"portClose", "portOpen", b"portOpen", "pprofRequest", b"pprofRequest", "pprofResponse", b"pprofResponse", "protocolError", b"protocolError", "proxyGoingAway", b"proxyGoingAway", "read", b"read", "readMetaRequest", b"readMetaRequest", "readMetaResponse", b"readMetaResponse", "readVCR", b"readVCR", "readdir", b"readdir", "record", b"record", "recv", b"recv", "redirect", b"redirect", "ref", b"ref", "remove", b"remove", "replspaceApiCloseFile", b"replspaceApiCloseFile", "replspaceApiGetGitHubToken", b"replspaceApiGetGitHubToken", "replspaceApiGitHubToken", b"replspaceApiGitHubToken", "replspaceApiOpenFile", b"replspaceApiOpenFile", "resizeTerm", b"resizeTerm", "result", b"result", "roster", b"roster", "runConfigGetRequest", b"runConfigGetRequest", "runConfigGetResponse", b"runConfigGetResponse", "runContainedTest", b"runContainedTest", "runMain", b"runMain", "saneTerm", b"saneTerm", "send", b"send", "session", b"session", "sessionTimestampUpdated", b"sessionTimestampUpdated", "snapshotEvent", b"snapshotEvent", "startLSP", b"startLSP", "startVCR", b"startVCR", "stat", b"stat", "statRes", b"statRes", "state", b"state", "stderr", b"stderr", "subscribeFile", b"subscribeFile", "testResult", b"testResult", "toast", b"toast", "toolchainChanged", b"toolchainChanged", "toolchainGetRequest", b"toolchainGetRequest", "toolchainGetResponse", b"toolchainGetResponse", "traceInfo", b"traceInfo", "transfer", b"transfer", "transferCancel", b"transferCancel", "transferChunk", b"transferChunk", "transferComplete", b"transferComplete", "transferStart", b"transferStart", "tryRemove", b"tryRemove", "unfollowUser", b"unfollowUser", "updateSessionTimestamp", b"updateSessionTimestamp", "userEvent", b"userEvent", "write", b"write", "writeMetaRequest", b"writeMetaRequest", "writeMetaResponse", b"writeMetaResponse"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["body", b"body"]) -> typing_extensions.Literal["openChan", "openChanRes", "closeChan", "closeChanRes", "containerState", "portOpen", "portClose", "toast", "protocolError", "redirect", "alwaysOn", "runMain", "clear", "eval", "result", "input", "output", "error", "stderr", "log", "record", "saneTerm", "resizeTerm", "state", "ok", "persist", "persistMirror", "write", "remove", "move", "tryRemove", "mkdir", "stat", "statRes", "transferStart", "transferChunk", "transferComplete", "transferCancel", "transfer", "read", "readdir", "files", "file", "checkChanges", "changedFiles", "lintResults", "runContainedTest", "testResult", "debuggerStart", "debuggerStep", "debuggerStatus", "ensurePackages", "ping", "pong", "hello", "goodbye", "proxyGoingAway", "hint", "connect", "send", "recv", "disconnect", "fileAuthReq", "fileAuthRes", "mutliFileAuthRes", "listObjects", "listObjectsResp", "ot", "otstatus", "otLinkFile", "otLinkFileResponse", "otNewCursor", "otDeleteCursor", "otFetchRequest", "otFetchResponse", "otTransformSelectionRequest", "otTransformSelectionResponse", "flush", "debug", "startVCR", "readVCR", "VCRLog", "auth", "execInfo", "subscribeFile", "fileEvent", "roster", "join", "part", "openFile", "fileOpened", "followUser", "unfollowUser", "updateSessionTimestamp", "sessionTimestampUpdated", "exec", "packageSearch", "packageSearchResp", "packageInfo", "packageInfoResp", "packageAdd", "packageRemove", "packageInstall", "packageListSpecfile", "packageListSpecfileResp", "packageCacheSave", "chatMessage", "chatTyping", "chatScrollback", "fsSnapshot", "fsSnapshotEvent", "fsTakeLock", "fsReleaseLock", "hasCap", "snapshotEvent", "NoninteractiveFSChangeEvent", "pid1Config", "metrics", "bootStatus", "readMetaRequest", "readMetaResponse", "writeMetaRequest", "writeMetaResponse", "appendMetaRequest", "appendMetaResponse", "audio", "pprofRequest", "pprofResponse", "audio2", "PTYConfig", "debugMain", "debugState", "debugMainReply", "debugInput", "debugOutput", "debugStop", "debugLeave", "debugSessions", "debugAddBreakpointRequest", "debugUpdateBreakpointRequest", "debugRemoveBreakpointRequest", "debugBreakpointEvent", "dotReplitGetRequest", "dotReplitGetResponse", "runConfigGetRequest", "runConfigGetResponse", "dotReplitUpdateRequest", "dotReplitUpdateResponse", "startLSP", "firewallDenied", "nixPackageAddRequest", "nixPackageAddResponse", "nixPackageRemoveRequest", "nixPackageRemoveResponse", "nixPackageListRequest", "nixPackageListResponse", "nixChannelsRequest", "nixChannelsResponse", "nixChannelLatestStableRequest", "nixChannelLatestStableResponse", "nixPackageSearchRequest", "nixPackageSearchResponse", "userEvent", "replspaceApiOpenFile", "replspaceApiCloseFile", "replspaceApiGetGitHubToken", "replspaceApiGitHubToken", "focused", "nixModulesGetRequest", "nixModulesGetResponse", "nixModulesChanged", "nixModulesBuildRequest", "packageSetPackagerRequest", "packageSetPackagerResp", "toolchainGetRequest", "toolchainGetResponse", "toolchainChanged"] | None: ...

global___Command = Command

@typing_extensions.final
class NixPackageAddRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGES_FIELD_NUMBER: builtins.int
    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        packages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["packages", b"packages"]) -> None: ...

global___NixPackageAddRequest = NixPackageAddRequest

@typing_extensions.final
class NixPackageAddResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NixPackageAddResponse = NixPackageAddResponse

@typing_extensions.final
class NixPackageRemoveRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGES_FIELD_NUMBER: builtins.int
    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        packages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["packages", b"packages"]) -> None: ...

global___NixPackageRemoveRequest = NixPackageRemoveRequest

@typing_extensions.final
class NixPackageRemoveResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NixPackageRemoveResponse = NixPackageRemoveResponse

@typing_extensions.final
class NixPackageListRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NixPackageListRequest = NixPackageListRequest

@typing_extensions.final
class NixPackageListResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGES_FIELD_NUMBER: builtins.int
    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NixPackage]: ...
    def __init__(
        self,
        *,
        packages: collections.abc.Iterable[global___NixPackage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["packages", b"packages"]) -> None: ...

global___NixPackageListResponse = NixPackageListResponse

@typing_extensions.final
class NixPackage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    HOMEPAGEURL_FIELD_NUMBER: builtins.int
    MAINTAINERS_FIELD_NUMBER: builtins.int
    LICENSES_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    version: builtins.str
    @property
    def homepageURL(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def maintainers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def licenses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        version: builtins.str = ...,
        homepageURL: collections.abc.Iterable[builtins.str] | None = ...,
        maintainers: collections.abc.Iterable[builtins.str] | None = ...,
        licenses: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "homepageURL", b"homepageURL", "licenses", b"licenses", "maintainers", b"maintainers", "name", b"name", "version", b"version"]) -> None: ...

global___NixPackage = NixPackage

@typing_extensions.final
class NixChannelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NixChannelsRequest = NixChannelsRequest

@typing_extensions.final
class NixChannelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        channels: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channels", b"channels"]) -> None: ...

global___NixChannelsResponse = NixChannelsResponse

@typing_extensions.final
class NixChannelLatestStableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NixChannelLatestStableRequest = NixChannelLatestStableRequest

@typing_extensions.final
class NixChannelLatestStableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_FIELD_NUMBER: builtins.int
    channel: builtins.str
    def __init__(
        self,
        *,
        channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel", b"channel"]) -> None: ...

global___NixChannelLatestStableResponse = NixChannelLatestStableResponse

@typing_extensions.final
class NixPackageSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.str
    def __init__(
        self,
        *,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query"]) -> None: ...

global___NixPackageSearchRequest = NixPackageSearchRequest

@typing_extensions.final
class NixPackageSearchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGES_FIELD_NUMBER: builtins.int
    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NixPackage]: ...
    def __init__(
        self,
        *,
        packages: collections.abc.Iterable[global___NixPackage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["packages", b"packages"]) -> None: ...

global___NixPackageSearchResponse = NixPackageSearchResponse

@typing_extensions.final
class StartLSP(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    LANGUAGESERVERID_FIELD_NUMBER: builtins.int
    language: builtins.str
    languageServerId: builtins.str
    def __init__(
        self,
        *,
        language: builtins.str = ...,
        languageServerId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["language", b"language", "languageServerId", b"languageServerId"]) -> None: ...

global___StartLSP = StartLSP

@typing_extensions.final
class Audio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___Audio = Audio

@typing_extensions.final
class Audio2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    SAMPLES_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    samples: builtins.int
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[builtins.int] | None = ...,
        samples: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "samples", b"samples"]) -> None: ...

global___Audio2 = Audio2

@typing_extensions.final
class Preconditions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GENERATION_FIELD_NUMBER: builtins.int
    METAGENERATION_FIELD_NUMBER: builtins.int
    DOESNOTEXIST_FIELD_NUMBER: builtins.int
    generation: builtins.int
    metageneration: builtins.int
    doesNotExist: builtins.bool
    def __init__(
        self,
        *,
        generation: builtins.int = ...,
        metageneration: builtins.int = ...,
        doesNotExist: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["doesNotExist", b"doesNotExist", "generation", b"generation", "metageneration", b"metageneration"]) -> None: ...

global___Preconditions = Preconditions

@typing_extensions.final
class ReadMetaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    EXISTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    key: builtins.str
    exists: builtins.bool
    data: builtins.bytes
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        exists: builtins.bool = ...,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "exists", b"exists", "key", b"key"]) -> None: ...

global___ReadMetaRequest = ReadMetaRequest

@typing_extensions.final
class ReadMetaResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    EXISTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    METAGENERATION_FIELD_NUMBER: builtins.int
    key: builtins.str
    exists: builtins.bool
    data: builtins.bytes
    generation: builtins.int
    metageneration: builtins.int
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        exists: builtins.bool = ...,
        data: builtins.bytes = ...,
        generation: builtins.int = ...,
        metageneration: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "exists", b"exists", "generation", b"generation", "key", b"key", "metageneration", b"metageneration"]) -> None: ...

global___ReadMetaResponse = ReadMetaResponse

@typing_extensions.final
class WriteMetaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    PRECONDITIONS_FIELD_NUMBER: builtins.int
    key: builtins.str
    data: builtins.bytes
    @property
    def preconditions(self) -> global___Preconditions: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        data: builtins.bytes = ...,
        preconditions: global___Preconditions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preconditions", b"preconditions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "key", b"key", "preconditions", b"preconditions"]) -> None: ...

global___WriteMetaRequest = WriteMetaRequest

@typing_extensions.final
class WriteMetaResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GENERATION_FIELD_NUMBER: builtins.int
    METAGENERATION_FIELD_NUMBER: builtins.int
    generation: builtins.int
    metageneration: builtins.int
    def __init__(
        self,
        *,
        generation: builtins.int = ...,
        metageneration: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["generation", b"generation", "metageneration", b"metageneration"]) -> None: ...

global___WriteMetaResponse = WriteMetaResponse

@typing_extensions.final
class AppendMetaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    PRECONDITIONS_FIELD_NUMBER: builtins.int
    key: builtins.str
    data: builtins.bytes
    @property
    def preconditions(self) -> global___Preconditions: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        data: builtins.bytes = ...,
        preconditions: global___Preconditions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preconditions", b"preconditions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "key", b"key", "preconditions", b"preconditions"]) -> None: ...

global___AppendMetaRequest = AppendMetaRequest

@typing_extensions.final
class AppendMetaResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GENERATION_FIELD_NUMBER: builtins.int
    METAGENERATION_FIELD_NUMBER: builtins.int
    generation: builtins.int
    metageneration: builtins.int
    def __init__(
        self,
        *,
        generation: builtins.int = ...,
        metageneration: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["generation", b"generation", "metageneration", b"metageneration"]) -> None: ...

global___AppendMetaResponse = AppendMetaResponse

@typing_extensions.final
class BootStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Stage:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BootStatus._Stage.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HANDSHAKE: BootStatus._Stage.ValueType  # 0
        ACQUIRING: BootStatus._Stage.ValueType  # 3
        COMPLETE: BootStatus._Stage.ValueType  # 4
        PROXY: BootStatus._Stage.ValueType  # 5
        PULL_FILES: BootStatus._Stage.ValueType  # 6
        LOAD_BLOCK: BootStatus._Stage.ValueType  # 7
        BLOCK_MIGRATION: BootStatus._Stage.ValueType  # 9
        RETRY: BootStatus._Stage.ValueType  # 8

    class Stage(_Stage, metaclass=_StageEnumTypeWrapper): ...
    HANDSHAKE: BootStatus.Stage.ValueType  # 0
    ACQUIRING: BootStatus.Stage.ValueType  # 3
    COMPLETE: BootStatus.Stage.ValueType  # 4
    PROXY: BootStatus.Stage.ValueType  # 5
    PULL_FILES: BootStatus.Stage.ValueType  # 6
    LOAD_BLOCK: BootStatus.Stage.ValueType  # 7
    BLOCK_MIGRATION: BootStatus.Stage.ValueType  # 9
    RETRY: BootStatus.Stage.ValueType  # 8

    STAGE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    stage: global___BootStatus.Stage.ValueType
    progress: builtins.int
    total: builtins.int
    def __init__(
        self,
        *,
        stage: global___BootStatus.Stage.ValueType = ...,
        progress: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["progress", b"progress", "stage", b"stage", "total", b"total"]) -> None: ...

global___BootStatus = BootStatus

@typing_extensions.final
class Pid1Config(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CWD_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    NOSTORE_FIELD_NUMBER: builtins.int
    NONINTERACTIVEFSCHANGE_FIELD_NUMBER: builtins.int
    cwd: builtins.str
    language: builtins.str
    @property
    def env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    noStore: builtins.bool
    noninteractiveFSChange: builtins.bool
    def __init__(
        self,
        *,
        cwd: builtins.str = ...,
        language: builtins.str = ...,
        env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        noStore: builtins.bool = ...,
        noninteractiveFSChange: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cwd", b"cwd", "env", b"env", "language", b"language", "noStore", b"noStore", "noninteractiveFSChange", b"noninteractiveFSChange"]) -> None: ...

global___Pid1Config = Pid1Config

@typing_extensions.final
class FSLock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___FSLock = FSLock

@typing_extensions.final
class FSSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FSSnapshot = FSSnapshot

@typing_extensions.final
class FSSnapshotEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCES_FIELD_NUMBER: builtins.int
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        sources: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sources", b"sources"]) -> None: ...

global___FSSnapshotEvent = FSSnapshotEvent

@typing_extensions.final
class SnapshotEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCES_FIELD_NUMBER: builtins.int
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        sources: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sources", b"sources"]) -> None: ...

global___SnapshotEvent = SnapshotEvent

@typing_extensions.final
class SubscribeFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]: ...
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[global___File] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files"]) -> None: ...

global___SubscribeFile = SubscribeFile

@typing_extensions.final
class FileEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Op:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OpEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FileEvent._Op.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        Create: FileEvent._Op.ValueType  # 0
        Move: FileEvent._Op.ValueType  # 1
        Remove: FileEvent._Op.ValueType  # 2
        Modify: FileEvent._Op.ValueType  # 3

    class Op(_Op, metaclass=_OpEnumTypeWrapper): ...
    Create: FileEvent.Op.ValueType  # 0
    Move: FileEvent.Op.ValueType  # 1
    Remove: FileEvent.Op.ValueType  # 2
    Modify: FileEvent.Op.ValueType  # 3

    FILE_FIELD_NUMBER: builtins.int
    DEST_FIELD_NUMBER: builtins.int
    OP_FIELD_NUMBER: builtins.int
    @property
    def file(self) -> global___File: ...
    @property
    def dest(self) -> global___File: ...
    op: global___FileEvent.Op.ValueType
    def __init__(
        self,
        *,
        file: global___File | None = ...,
        dest: global___File | None = ...,
        op: global___FileEvent.Op.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dest", b"dest", "file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dest", b"dest", "file", b"file", "op", b"op"]) -> None: ...

global___FileEvent = FileEvent

@typing_extensions.final
class Flush(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Consistency:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConsistencyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Flush._Consistency.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PermanentStorage: Flush._Consistency.ValueType  # 0
        Disk: Flush._Consistency.ValueType  # 1

    class Consistency(_Consistency, metaclass=_ConsistencyEnumTypeWrapper): ...
    PermanentStorage: Flush.Consistency.ValueType  # 0
    Disk: Flush.Consistency.ValueType  # 1

    CONSISTENCY_FIELD_NUMBER: builtins.int
    consistency: global___Flush.Consistency.ValueType
    def __init__(
        self,
        *,
        consistency: global___Flush.Consistency.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["consistency", b"consistency"]) -> None: ...

global___Flush = Flush

@typing_extensions.final
class OTLinkFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    HIGHCONSISTENCY_FIELD_NUMBER: builtins.int
    OBSOLETEUSEMODTIME_FIELD_NUMBER: builtins.int
    @property
    def file(self) -> global___File: ...
    highConsistency: builtins.bool
    OBSOLETEUseModTime: builtins.bool
    def __init__(
        self,
        *,
        file: global___File | None = ...,
        highConsistency: builtins.bool = ...,
        OBSOLETEUseModTime: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["OBSOLETEUseModTime", b"OBSOLETEUseModTime", "file", b"file", "highConsistency", b"highConsistency"]) -> None: ...

global___OTLinkFile = OTLinkFile

@typing_extensions.final
class OTLinkFileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    LINKEDFILE_FIELD_NUMBER: builtins.int
    version: builtins.int
    @property
    def linkedFile(self) -> global___File: ...
    def __init__(
        self,
        *,
        version: builtins.int = ...,
        linkedFile: global___File | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["linkedFile", b"linkedFile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["linkedFile", b"linkedFile", "version", b"version"]) -> None: ...

global___OTLinkFileResponse = OTLinkFileResponse

@typing_extensions.final
class Auth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    CONTAINERID_FIELD_NUMBER: builtins.int
    token: builtins.str
    containerID: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        containerID: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containerID", b"containerID", "token", b"token"]) -> None: ...

global___Auth = Auth

@typing_extensions.final
class VCREntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Direction:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DirectionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VCREntry._Direction.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IN: VCREntry._Direction.ValueType  # 0
        OUT: VCREntry._Direction.ValueType  # 1

    class Direction(_Direction, metaclass=_DirectionEnumTypeWrapper): ...
    IN: VCREntry.Direction.ValueType  # 0
    OUT: VCREntry.Direction.ValueType  # 1

    TIMESTAMP_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    REPLID_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    direction: global___VCREntry.Direction.ValueType
    @property
    def command(self) -> global___Command: ...
    uid: builtins.str
    replid: builtins.str
    def __init__(
        self,
        *,
        timestamp: builtins.int = ...,
        direction: global___VCREntry.Direction.ValueType = ...,
        command: global___Command | None = ...,
        uid: builtins.str = ...,
        replid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["command", b"command"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "direction", b"direction", "replid", b"replid", "timestamp", b"timestamp", "uid", b"uid"]) -> None: ...

global___VCREntry = VCREntry

@typing_extensions.final
class StartVCR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartVCR = StartVCR

@typing_extensions.final
class ReadVCR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReadVCR = ReadVCR

@typing_extensions.final
class VCRLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_FIELD_NUMBER: builtins.int
    LOGFILE_FIELD_NUMBER: builtins.int
    @property
    def log(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VCREntry]: ...
    @property
    def logfile(self) -> global___File: ...
    def __init__(
        self,
        *,
        log: collections.abc.Iterable[global___VCREntry] | None = ...,
        logfile: global___File | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logfile", b"logfile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log", b"log", "logfile", b"logfile"]) -> None: ...

global___VCRLog = VCRLog

@typing_extensions.final
class ExecInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    reason: builtins.str
    def __init__(
        self,
        *,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "reason", b"reason"]) -> None: ...

global___ExecInfo = ExecInfo

@typing_extensions.final
class Debug(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___Debug = Debug

@typing_extensions.final
class FileAuthReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    @property
    def file(self) -> global___File: ...
    method: global___FileAuthMethod.ValueType
    def __init__(
        self,
        *,
        file: global___File | None = ...,
        method: global___FileAuthMethod.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "method", b"method"]) -> None: ...

global___FileAuthReq = FileAuthReq

@typing_extensions.final
class MultiFileAuthRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUT_FIELD_NUMBER: builtins.int
    DEL_FIELD_NUMBER: builtins.int
    GET_FIELD_NUMBER: builtins.int
    @property
    def put(self) -> global___FileAuthRes: ...
    @property
    def get(self) -> global___FileAuthRes: ...
    def __init__(
        self,
        *,
        put: global___FileAuthRes | None = ...,
        get: global___FileAuthRes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["del", b"del", "get", b"get", "put", b"put"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["del", b"del", "get", b"get", "put", b"put"]) -> None: ...

global___MultiFileAuthRes = MultiFileAuthRes

@typing_extensions.final
class FileAuthRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    REPLERROR_FIELD_NUMBER: builtins.int
    @property
    def file(self) -> global___File: ...
    url: builtins.str
    method: global___FileAuthMethod.ValueType
    expire: builtins.int
    error: builtins.str
    replError: builtins.bool
    def __init__(
        self,
        *,
        file: global___File | None = ...,
        url: builtins.str = ...,
        method: global___FileAuthMethod.ValueType = ...,
        expire: builtins.int = ...,
        error: builtins.str = ...,
        replError: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "expire", b"expire", "file", b"file", "method", b"method", "replError", b"replError", "url", b"url"]) -> None: ...

global___FileAuthRes = FileAuthRes

@typing_extensions.final
class ListObjects(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFIX_FIELD_NUMBER: builtins.int
    prefix: builtins.str
    def __init__(
        self,
        *,
        prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prefix", b"prefix"]) -> None: ...

global___ListObjects = ListObjects

@typing_extensions.final
class ListObjectsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def objects(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        objects: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["objects", b"objects"]) -> None: ...

global___ListObjectsResp = ListObjectsResp

@typing_extensions.final
class Disconnect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    error: builtins.str
    def __init__(
        self,
        *,
        error: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error"]) -> None: ...

global___Disconnect = Disconnect

@typing_extensions.final
class Send(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUFF_FIELD_NUMBER: builtins.int
    buff: builtins.bytes
    def __init__(
        self,
        *,
        buff: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buff", b"buff"]) -> None: ...

global___Send = Send

@typing_extensions.final
class Recv(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUFF_FIELD_NUMBER: builtins.int
    buff: builtins.bytes
    def __init__(
        self,
        *,
        buff: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buff", b"buff"]) -> None: ...

global___Recv = Recv

@typing_extensions.final
class Connect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTO_FIELD_NUMBER: builtins.int
    ADDR_FIELD_NUMBER: builtins.int
    proto: builtins.str
    addr: builtins.str
    def __init__(
        self,
        *,
        proto: builtins.str = ...,
        addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["addr", b"addr", "proto", b"proto"]) -> None: ...

global___Connect = Connect

@typing_extensions.final
class Hint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___Hint = Hint

@typing_extensions.final
class Ping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Ping = Ping

@typing_extensions.final
class Pong(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Pong = Pong

@typing_extensions.final
class Hello(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    userid: builtins.int
    username: builtins.str
    token: builtins.str
    def __init__(
        self,
        *,
        userid: builtins.int = ...,
        username: builtins.str = ...,
        token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token", "userid", b"userid", "username", b"username"]) -> None: ...

global___Hello = Hello

@typing_extensions.final
class Goodbye(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Goodbye = Goodbye

@typing_extensions.final
class CheckChanges(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CheckChanges = CheckChanges

@typing_extensions.final
class EnsurePackages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTALL_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    install: builtins.bool
    @property
    def file(self) -> global___File: ...
    def __init__(
        self,
        *,
        install: builtins.bool = ...,
        file: global___File | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "install", b"install"]) -> None: ...

global___EnsurePackages = EnsurePackages

@typing_extensions.final
class Start(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Start = Start

@typing_extensions.final
class DebugStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DONE_FIELD_NUMBER: builtins.int
    STACK_FIELD_NUMBER: builtins.int
    done: builtins.bool
    @property
    def stack(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StackFrame]: ...
    def __init__(
        self,
        *,
        done: builtins.bool = ...,
        stack: collections.abc.Iterable[global___StackFrame] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["done", b"done", "stack", b"stack"]) -> None: ...

global___DebugStatus = DebugStatus

@typing_extensions.final
class StackFrame(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    function: builtins.str
    line: builtins.int
    def __init__(
        self,
        *,
        function: builtins.str = ...,
        line: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["function", b"function", "line", b"line"]) -> None: ...

global___StackFrame = StackFrame

@typing_extensions.final
class ContainedTest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUITE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def suite(self) -> global___File: ...
    @property
    def project(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]: ...
    def __init__(
        self,
        *,
        suite: global___File | None = ...,
        project: collections.abc.Iterable[global___File] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["suite", b"suite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project", b"project", "suite", b"suite"]) -> None: ...

global___ContainedTest = ContainedTest

@typing_extensions.final
class TestResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSED_FIELD_NUMBER: builtins.int
    STDERR_FIELD_NUMBER: builtins.int
    FAILS_FIELD_NUMBER: builtins.int
    passed: builtins.bool
    stderr: builtins.str
    @property
    def fails(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TestFailure]: ...
    def __init__(
        self,
        *,
        passed: builtins.bool = ...,
        stderr: builtins.str = ...,
        fails: collections.abc.Iterable[global___TestFailure] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fails", b"fails", "passed", b"passed", "stderr", b"stderr"]) -> None: ...

global___TestResult = TestResult

@typing_extensions.final
class TestFailure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TRACE_FIELD_NUMBER: builtins.int
    name: builtins.str
    trace: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        trace: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "trace", b"trace"]) -> None: ...

global___TestFailure = TestFailure

@typing_extensions.final
class ResizeTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROWS_FIELD_NUMBER: builtins.int
    COLS_FIELD_NUMBER: builtins.int
    rows: builtins.int
    cols: builtins.int
    def __init__(
        self,
        *,
        rows: builtins.int = ...,
        cols: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cols", b"cols", "rows", b"rows"]) -> None: ...

global___ResizeTerm = ResizeTerm

@typing_extensions.final
class SaneTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SaneTerm = SaneTerm

@typing_extensions.final
class LintResults(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LintResult]: ...
    def __init__(
        self,
        *,
        results: collections.abc.Iterable[global___LintResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["results", b"results"]) -> None: ...

global___LintResults = LintResults

@typing_extensions.final
class LintResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ROW_FIELD_NUMBER: builtins.int
    COLUMN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    text: builtins.str
    row: builtins.int
    column: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        row: builtins.int = ...,
        column: builtins.int = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["column", b"column", "row", b"row", "text", b"text", "type", b"type"]) -> None: ...

global___LintResult = LintResult

@typing_extensions.final
class OK(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OK = OK

@typing_extensions.final
class Move(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLDPATH_FIELD_NUMBER: builtins.int
    NEWPATH_FIELD_NUMBER: builtins.int
    oldPath: builtins.str
    newPath: builtins.str
    def __init__(
        self,
        *,
        oldPath: builtins.str = ...,
        newPath: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["newPath", b"newPath", "oldPath", b"oldPath"]) -> None: ...

global___Move = Move

@typing_extensions.final
class Files(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]: ...
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[global___File] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files"]) -> None: ...

global___Files = Files

@typing_extensions.final
class StatResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXISTS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    FILEMODE_FIELD_NUMBER: builtins.int
    MODTIME_FIELD_NUMBER: builtins.int
    exists: builtins.bool
    type: global___File.Type.ValueType
    size: builtins.int
    fileMode: builtins.str
    modTime: builtins.int
    def __init__(
        self,
        *,
        exists: builtins.bool = ...,
        type: global___File.Type.ValueType = ...,
        size: builtins.int = ...,
        fileMode: builtins.str = ...,
        modTime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exists", b"exists", "fileMode", b"fileMode", "modTime", b"modTime", "size", b"size", "type", b"type"]) -> None: ...

global___StatResult = StatResult

@typing_extensions.final
class File(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[File._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REGULAR: File._Type.ValueType  # 0
        DIRECTORY: File._Type.ValueType  # 1

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    REGULAR: File.Type.ValueType  # 0
    DIRECTORY: File.Type.ValueType  # 1

    PATH_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    path: builtins.str
    type: global___File.Type.ValueType
    content: builtins.bytes
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        type: global___File.Type.ValueType = ...,
        content: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "path", b"path", "type", b"type"]) -> None: ...

global___File = File

@typing_extensions.final
class Transfer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___Transfer = Transfer

@typing_extensions.final
class TransferStart(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    path: builtins.str
    size: builtins.int
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "size", b"size"]) -> None: ...

global___TransferStart = TransferStart

@typing_extensions.final
class TransferChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    id: builtins.str
    content: builtins.bytes
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        content: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "id", b"id"]) -> None: ...

global___TransferChunk = TransferChunk

@typing_extensions.final
class TransferComplete(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CRC32_FIELD_NUMBER: builtins.int
    id: builtins.str
    crc32: builtins.int
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        crc32: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["crc32", b"crc32", "id", b"id"]) -> None: ...

global___TransferComplete = TransferComplete

@typing_extensions.final
class Clear(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Clear = Clear

@typing_extensions.final
class Toast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___Toast = Toast

@typing_extensions.final
class ProtocolError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___ProtocolError = ProtocolError

@typing_extensions.final
class Redirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___Redirect = Redirect

@typing_extensions.final
class AlwaysOn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable"]) -> None: ...

global___AlwaysOn = AlwaysOn

@typing_extensions.final
class RunMain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RunMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RunModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RunMain._RunMode.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RUN: RunMain._RunMode.ValueType  # 0
        RECORD: RunMain._RunMode.ValueType  # 1

    class RunMode(_RunMode, metaclass=_RunModeEnumTypeWrapper): ...
    RUN: RunMain.RunMode.ValueType  # 0
    RECORD: RunMain.RunMode.ValueType  # 1

    RUNMODE_FIELD_NUMBER: builtins.int
    IDEMPOTENT_FIELD_NUMBER: builtins.int
    FILEPATH_FIELD_NUMBER: builtins.int
    RUNNERID_FIELD_NUMBER: builtins.int
    runMode: global___RunMain.RunMode.ValueType
    idempotent: builtins.bool
    filePath: builtins.str
    runnerId: builtins.str
    def __init__(
        self,
        *,
        runMode: global___RunMain.RunMode.ValueType = ...,
        idempotent: builtins.bool = ...,
        filePath: builtins.str = ...,
        runnerId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filePath", b"filePath", "idempotent", b"idempotent", "runMode", b"runMode", "runnerId", b"runnerId"]) -> None: ...

global___RunMain = RunMain

@typing_extensions.final
class OpenChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OpenChannel._Action.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CREATE: OpenChannel._Action.ValueType  # 0
        ATTACH: OpenChannel._Action.ValueType  # 1
        ATTACH_OR_CREATE: OpenChannel._Action.ValueType  # 2

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    CREATE: OpenChannel.Action.ValueType  # 0
    ATTACH: OpenChannel.Action.ValueType  # 1
    ATTACH_OR_CREATE: OpenChannel.Action.ValueType  # 2

    SERVICE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    service: builtins.str
    name: builtins.str
    action: global___OpenChannel.Action.ValueType
    id: builtins.int
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        name: builtins.str = ...,
        action: global___OpenChannel.Action.ValueType = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "id", b"id", "name", b"name", "service", b"service"]) -> None: ...

global___OpenChannel = OpenChannel

@typing_extensions.final
class OpenChannelRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _State:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OpenChannelRes._State.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CREATED: OpenChannelRes._State.ValueType  # 0
        ATTACHED: OpenChannelRes._State.ValueType  # 1
        ERROR: OpenChannelRes._State.ValueType  # 2

    class State(_State, metaclass=_StateEnumTypeWrapper): ...
    CREATED: OpenChannelRes.State.ValueType  # 0
    ATTACHED: OpenChannelRes.State.ValueType  # 1
    ERROR: OpenChannelRes.State.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    id: builtins.int
    state: global___OpenChannelRes.State.ValueType
    error: builtins.str
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        state: global___OpenChannelRes.State.ValueType = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "id", b"id", "state", b"state"]) -> None: ...

global___OpenChannelRes = OpenChannelRes

@typing_extensions.final
class CloseChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CloseChannel._Action.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DISCONNECT: CloseChannel._Action.ValueType  # 0
        TRY_CLOSE: CloseChannel._Action.ValueType  # 1
        CLOSE: CloseChannel._Action.ValueType  # 2

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    DISCONNECT: CloseChannel.Action.ValueType  # 0
    TRY_CLOSE: CloseChannel.Action.ValueType  # 1
    CLOSE: CloseChannel.Action.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    id: builtins.int
    action: global___CloseChannel.Action.ValueType
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        action: global___CloseChannel.Action.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "id", b"id"]) -> None: ...

global___CloseChannel = CloseChannel

@typing_extensions.final
class CloseChannelRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CloseChannelRes._Status.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DISCONNECT: CloseChannelRes._Status.ValueType  # 0
        CLOSE: CloseChannelRes._Status.ValueType  # 1
        NOTHING: CloseChannelRes._Status.ValueType  # 2

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    DISCONNECT: CloseChannelRes.Status.ValueType  # 0
    CLOSE: CloseChannelRes.Status.ValueType  # 1
    NOTHING: CloseChannelRes.Status.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.int
    status: global___CloseChannelRes.Status.ValueType
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        status: global___CloseChannelRes.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "status", b"status"]) -> None: ...

global___CloseChannelRes = CloseChannelRes

@typing_extensions.final
class ContainerState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _State:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ContainerState._State.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SLEEP: ContainerState._State.ValueType  # 0
        READY: ContainerState._State.ValueType  # 1

    class State(_State, metaclass=_StateEnumTypeWrapper): ...
    SLEEP: ContainerState.State.ValueType  # 0
    READY: ContainerState.State.ValueType  # 1

    STATE_FIELD_NUMBER: builtins.int
    state: global___ContainerState.State.ValueType
    def __init__(
        self,
        *,
        state: global___ContainerState.State.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___ContainerState = ContainerState

@typing_extensions.final
class PortOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORWARDED_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    EXTERNALPORT_FIELD_NUMBER: builtins.int
    forwarded: builtins.bool
    port: builtins.int
    address: builtins.str
    externalPort: builtins.int
    def __init__(
        self,
        *,
        forwarded: builtins.bool = ...,
        port: builtins.int = ...,
        address: builtins.str = ...,
        externalPort: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "externalPort", b"externalPort", "forwarded", b"forwarded", "port", b"port"]) -> None: ...

global___PortOpen = PortOpen

@typing_extensions.final
class PortClose(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    EXTERNALPORT_FIELD_NUMBER: builtins.int
    port: builtins.int
    address: builtins.str
    externalPort: builtins.int
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        address: builtins.str = ...,
        externalPort: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "externalPort", b"externalPort", "port", b"port"]) -> None: ...

global___PortClose = PortClose

@typing_extensions.final
class OTFetchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONFROM_FIELD_NUMBER: builtins.int
    VERSIONTO_FIELD_NUMBER: builtins.int
    versionFrom: builtins.int
    versionTo: builtins.int
    def __init__(
        self,
        *,
        versionFrom: builtins.int = ...,
        versionTo: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["versionFrom", b"versionFrom", "versionTo", b"versionTo"]) -> None: ...

global___OTFetchRequest = OTFetchRequest

@typing_extensions.final
class OTFetchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKETS_FIELD_NUMBER: builtins.int
    @property
    def packets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OTPacket]: ...
    def __init__(
        self,
        *,
        packets: collections.abc.Iterable[global___OTPacket] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["packets", b"packets"]) -> None: ...

global___OTFetchResponse = OTFetchResponse

@typing_extensions.final
class OTTransformSelectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEXSTART_FIELD_NUMBER: builtins.int
    INDEXEND_FIELD_NUMBER: builtins.int
    VERSIONFROM_FIELD_NUMBER: builtins.int
    VERSIONTO_FIELD_NUMBER: builtins.int
    indexStart: builtins.int
    indexEnd: builtins.int
    versionFrom: builtins.int
    versionTo: builtins.int
    def __init__(
        self,
        *,
        indexStart: builtins.int = ...,
        indexEnd: builtins.int = ...,
        versionFrom: builtins.int = ...,
        versionTo: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["indexEnd", b"indexEnd", "indexStart", b"indexStart", "versionFrom", b"versionFrom", "versionTo", b"versionTo"]) -> None: ...

global___OTTransformSelectionRequest = OTTransformSelectionRequest

@typing_extensions.final
class OTTransformSelectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEXSTART_FIELD_NUMBER: builtins.int
    INDEXEND_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    indexStart: builtins.int
    indexEnd: builtins.int
    version: builtins.int
    def __init__(
        self,
        *,
        indexStart: builtins.int = ...,
        indexEnd: builtins.int = ...,
        version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["indexEnd", b"indexEnd", "indexStart", b"indexStart", "version", b"version"]) -> None: ...

global___OTTransformSelectionResponse = OTTransformSelectionResponse

@typing_extensions.final
class OTPacket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Author:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AuthorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OTPacket._Author.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        USER: OTPacket._Author.ValueType  # 0
        GHOSTWRITER: OTPacket._Author.ValueType  # 1

    class Author(_Author, metaclass=_AuthorEnumTypeWrapper): ...
    USER: OTPacket.Author.ValueType  # 0
    GHOSTWRITER: OTPacket.Author.ValueType  # 1

    SPOOKYVERSION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    OP_FIELD_NUMBER: builtins.int
    CRC32_FIELD_NUMBER: builtins.int
    COMMITTED_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    USERID_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    spookyVersion: builtins.int
    version: builtins.int
    @property
    def op(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OTOpComponent]: ...
    crc32: builtins.int
    @property
    def committed(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    nonce: builtins.int
    userId: builtins.int
    author: global___OTPacket.Author.ValueType
    def __init__(
        self,
        *,
        spookyVersion: builtins.int = ...,
        version: builtins.int = ...,
        op: collections.abc.Iterable[global___OTOpComponent] | None = ...,
        crc32: builtins.int = ...,
        committed: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        nonce: builtins.int = ...,
        userId: builtins.int = ...,
        author: global___OTPacket.Author.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["committed", b"committed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "committed", b"committed", "crc32", b"crc32", "nonce", b"nonce", "op", b"op", "spookyVersion", b"spookyVersion", "userId", b"userId", "version", b"version"]) -> None: ...

global___OTPacket = OTPacket

@typing_extensions.final
class OTOpComponent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SKIP_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    INSERT_FIELD_NUMBER: builtins.int
    skip: builtins.int
    delete: builtins.int
    insert: builtins.str
    def __init__(
        self,
        *,
        skip: builtins.int = ...,
        delete: builtins.int = ...,
        insert: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delete", b"delete", "insert", b"insert", "opComponent", b"opComponent", "skip", b"skip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete", b"delete", "insert", b"insert", "opComponent", b"opComponent", "skip", b"skip"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["opComponent", b"opComponent"]) -> typing_extensions.Literal["skip", "delete", "insert"] | None: ...

global___OTOpComponent = OTOpComponent

@typing_extensions.final
class OTStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENTS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    LINKEDFILE_FIELD_NUMBER: builtins.int
    CURSORS_FIELD_NUMBER: builtins.int
    contents: builtins.str
    version: builtins.int
    @property
    def linkedFile(self) -> global___File: ...
    @property
    def cursors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OTCursor]: ...
    def __init__(
        self,
        *,
        contents: builtins.str = ...,
        version: builtins.int = ...,
        linkedFile: global___File | None = ...,
        cursors: collections.abc.Iterable[global___OTCursor] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["linkedFile", b"linkedFile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contents", b"contents", "cursors", b"cursors", "linkedFile", b"linkedFile", "version", b"version"]) -> None: ...

global___OTStatus = OTStatus

@typing_extensions.final
class OTCursor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSITION_FIELD_NUMBER: builtins.int
    SELECTIONSTART_FIELD_NUMBER: builtins.int
    SELECTIONEND_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    position: builtins.int
    selectionStart: builtins.int
    selectionEnd: builtins.int
    @property
    def user(self) -> global___User: ...
    id: builtins.str
    def __init__(
        self,
        *,
        position: builtins.int = ...,
        selectionStart: builtins.int = ...,
        selectionEnd: builtins.int = ...,
        user: global___User | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "position", b"position", "selectionEnd", b"selectionEnd", "selectionStart", b"selectionStart", "user", b"user"]) -> None: ...

global___OTCursor = OTCursor

@typing_extensions.final
class ChatMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    username: builtins.str
    text: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "username", b"username"]) -> None: ...

global___ChatMessage = ChatMessage

@typing_extensions.final
class ChatTyping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    TYPING_FIELD_NUMBER: builtins.int
    username: builtins.str
    typing: builtins.bool
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        typing: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["typing", b"typing", "username", b"username"]) -> None: ...

global___ChatTyping = ChatTyping

@typing_extensions.final
class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    SESSION_FIELD_NUMBER: builtins.int
    TEAMS_FIELD_NUMBER: builtins.int
    BIO_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    PROFILEIMAGE_FIELD_NUMBER: builtins.int
    id: builtins.int
    name: builtins.str
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    session: builtins.int
    @property
    def teams(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    bio: builtins.str
    url: builtins.str
    profileImage: builtins.str
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        roles: collections.abc.Iterable[builtins.str] | None = ...,
        session: builtins.int = ...,
        teams: collections.abc.Iterable[builtins.str] | None = ...,
        bio: builtins.str = ...,
        url: builtins.str = ...,
        profileImage: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bio", b"bio", "id", b"id", "name", b"name", "profileImage", b"profileImage", "roles", b"roles", "session", b"session", "teams", b"teams", "url", b"url"]) -> None: ...

global___User = User

@typing_extensions.final
class Roster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___User]: ...
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileOpened]: ...
    def __init__(
        self,
        *,
        user: collections.abc.Iterable[global___User] | None = ...,
        files: collections.abc.Iterable[global___FileOpened] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files", "user", b"user"]) -> None: ...

global___Roster = Roster

@typing_extensions.final
class OpenFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    file: builtins.str
    def __init__(
        self,
        *,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file"]) -> None: ...

global___OpenFile = OpenFile

@typing_extensions.final
class FileOpened(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERID_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    SESSION_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    userId: builtins.int
    file: builtins.str
    session: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        userId: builtins.int = ...,
        file: builtins.str = ...,
        session: builtins.int = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "session", b"session", "timestamp", b"timestamp", "userId", b"userId"]) -> None: ...

global___FileOpened = FileOpened

@typing_extensions.final
class ReplspaceApiOpenFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    WAITFORCLOSE_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    file: builtins.str
    waitForClose: builtins.bool
    nonce: builtins.str
    def __init__(
        self,
        *,
        file: builtins.str = ...,
        waitForClose: builtins.bool = ...,
        nonce: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "nonce", b"nonce", "waitForClose", b"waitForClose"]) -> None: ...

global___ReplspaceApiOpenFile = ReplspaceApiOpenFile

@typing_extensions.final
class ReplspaceApiCloseFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    file: builtins.str
    nonce: builtins.str
    def __init__(
        self,
        *,
        file: builtins.str = ...,
        nonce: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "nonce", b"nonce"]) -> None: ...

global___ReplspaceApiCloseFile = ReplspaceApiCloseFile

@typing_extensions.final
class ReplspaceApiGetGitHubToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NONCE_FIELD_NUMBER: builtins.int
    nonce: builtins.str
    def __init__(
        self,
        *,
        nonce: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nonce", b"nonce"]) -> None: ...

global___ReplspaceApiGetGitHubToken = ReplspaceApiGetGitHubToken

@typing_extensions.final
class ReplspaceApiGitHubToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NONCE_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    nonce: builtins.str
    token: builtins.str
    def __init__(
        self,
        *,
        nonce: builtins.str = ...,
        token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nonce", b"nonce", "token", b"token"]) -> None: ...

global___ReplspaceApiGitHubToken = ReplspaceApiGitHubToken

@typing_extensions.final
class Focused(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Focused = Focused

@typing_extensions.final
class UpdateSessionTimestamp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateSessionTimestamp = UpdateSessionTimestamp

@typing_extensions.final
class SessionTimestampUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    session: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        session: builtins.int = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["session", b"session", "timestamp", b"timestamp"]) -> None: ...

global___SessionTimestampUpdated = SessionTimestampUpdated

@typing_extensions.final
class FollowUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    session: builtins.int
    def __init__(
        self,
        *,
        session: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session", b"session"]) -> None: ...

global___FollowUser = FollowUser

@typing_extensions.final
class UnfollowUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    session: builtins.int
    def __init__(
        self,
        *,
        session: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session", b"session"]) -> None: ...

global___UnfollowUser = UnfollowUser

@typing_extensions.final
class Exec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Lifecycle:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LifecycleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Exec._Lifecycle.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NON_BLOCKING: Exec._Lifecycle.ValueType  # 0
        BLOCKING: Exec._Lifecycle.ValueType  # 1
        STDIN: Exec._Lifecycle.ValueType  # 2

    class Lifecycle(_Lifecycle, metaclass=_LifecycleEnumTypeWrapper): ...
    NON_BLOCKING: Exec.Lifecycle.ValueType  # 0
    BLOCKING: Exec.Lifecycle.ValueType  # 1
    STDIN: Exec.Lifecycle.ValueType  # 2

    @typing_extensions.final
    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARGS_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    BLOCKING_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    SPLITSTDERR_FIELD_NUMBER: builtins.int
    SPLITLOGS_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    blocking: builtins.bool
    lifecycle: global___Exec.Lifecycle.ValueType
    splitStderr: builtins.bool
    splitLogs: builtins.bool
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        blocking: builtins.bool = ...,
        lifecycle: global___Exec.Lifecycle.ValueType = ...,
        splitStderr: builtins.bool = ...,
        splitLogs: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "blocking", b"blocking", "env", b"env", "lifecycle", b"lifecycle", "splitLogs", b"splitLogs", "splitStderr", b"splitStderr"]) -> None: ...

global___Exec = Exec

@typing_extensions.final
class Package(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    HOMEPAGEURL_FIELD_NUMBER: builtins.int
    DOCUMENTATIONURL_FIELD_NUMBER: builtins.int
    SOURCECODEURL_FIELD_NUMBER: builtins.int
    BUGTRACKERURL_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    LICENSE_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    name: builtins.str
    spec: builtins.str
    description: builtins.str
    version: builtins.str
    homepageURL: builtins.str
    documentationURL: builtins.str
    sourceCodeURL: builtins.str
    bugTrackerURL: builtins.str
    author: builtins.str
    license: builtins.str
    @property
    def dependencies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Package]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        spec: builtins.str = ...,
        description: builtins.str = ...,
        version: builtins.str = ...,
        homepageURL: builtins.str = ...,
        documentationURL: builtins.str = ...,
        sourceCodeURL: builtins.str = ...,
        bugTrackerURL: builtins.str = ...,
        author: builtins.str = ...,
        license: builtins.str = ...,
        dependencies: collections.abc.Iterable[global___Package] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "bugTrackerURL", b"bugTrackerURL", "dependencies", b"dependencies", "description", b"description", "documentationURL", b"documentationURL", "homepageURL", b"homepageURL", "license", b"license", "name", b"name", "sourceCodeURL", b"sourceCodeURL", "spec", b"spec", "version", b"version"]) -> None: ...

global___Package = Package

@typing_extensions.final
class PackageSetPackagerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGERID_FIELD_NUMBER: builtins.int
    packagerId: builtins.str
    def __init__(
        self,
        *,
        packagerId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["packagerId", b"packagerId"]) -> None: ...

global___PackageSetPackagerRequest = PackageSetPackagerRequest

@typing_extensions.final
class PackageSetPackagerResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGERID_FIELD_NUMBER: builtins.int
    packagerId: builtins.str
    def __init__(
        self,
        *,
        packagerId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["packagerId", b"packagerId"]) -> None: ...

global___PackageSetPackagerResponse = PackageSetPackagerResponse

@typing_extensions.final
class PackageSearch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.str
    def __init__(
        self,
        *,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query"]) -> None: ...

global___PackageSearch = PackageSearch

@typing_extensions.final
class PackageSearchResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Package]: ...
    def __init__(
        self,
        *,
        results: collections.abc.Iterable[global___Package] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["results", b"results"]) -> None: ...

global___PackageSearchResp = PackageSearchResp

@typing_extensions.final
class PackageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PKG_FIELD_NUMBER: builtins.int
    @property
    def pkg(self) -> global___Package: ...
    def __init__(
        self,
        *,
        pkg: global___Package | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pkg", b"pkg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pkg", b"pkg"]) -> None: ...

global___PackageInfo = PackageInfo

@typing_extensions.final
class PackageInfoResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PKG_FIELD_NUMBER: builtins.int
    @property
    def pkg(self) -> global___Package: ...
    def __init__(
        self,
        *,
        pkg: global___Package | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pkg", b"pkg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pkg", b"pkg"]) -> None: ...

global___PackageInfoResp = PackageInfoResp

@typing_extensions.final
class PackageAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PKGS_FIELD_NUMBER: builtins.int
    @property
    def pkgs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Package]: ...
    def __init__(
        self,
        *,
        pkgs: collections.abc.Iterable[global___Package] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pkgs", b"pkgs"]) -> None: ...

global___PackageAdd = PackageAdd

@typing_extensions.final
class PackageRemove(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PKGS_FIELD_NUMBER: builtins.int
    @property
    def pkgs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Package]: ...
    def __init__(
        self,
        *,
        pkgs: collections.abc.Iterable[global___Package] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pkgs", b"pkgs"]) -> None: ...

global___PackageRemove = PackageRemove

@typing_extensions.final
class PackageInstall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROMHOSTING_FIELD_NUMBER: builtins.int
    fromHosting: builtins.bool
    def __init__(
        self,
        *,
        fromHosting: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fromHosting", b"fromHosting"]) -> None: ...

global___PackageInstall = PackageInstall

@typing_extensions.final
class PackageListSpecfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PackageListSpecfile = PackageListSpecfile

@typing_extensions.final
class PackageListSpecfileResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PKGS_FIELD_NUMBER: builtins.int
    @property
    def pkgs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Package]: ...
    def __init__(
        self,
        *,
        pkgs: collections.abc.Iterable[global___Package] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pkgs", b"pkgs"]) -> None: ...

global___PackageListSpecfileResp = PackageListSpecfileResp

@typing_extensions.final
class PackageCacheSave(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PackageCacheSave = PackageCacheSave

@typing_extensions.final
class ChatScrollback(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCROLLBACK_FIELD_NUMBER: builtins.int
    @property
    def scrollback(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChatMessage]: ...
    def __init__(
        self,
        *,
        scrollback: collections.abc.Iterable[global___ChatMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scrollback", b"scrollback"]) -> None: ...

global___ChatScrollback = ChatScrollback

@typing_extensions.final
class Metrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMETHEUSMETRICFAMILIES_FIELD_NUMBER: builtins.int
    @property
    def prometheusMetricFamilies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    def __init__(
        self,
        *,
        prometheusMetricFamilies: collections.abc.Iterable[builtins.bytes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prometheusMetricFamilies", b"prometheusMetricFamilies"]) -> None: ...

global___Metrics = Metrics

@typing_extensions.final
class PprofRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PPROFCPUPROFILEREQUEST_FIELD_NUMBER: builtins.int
    PPROFHEAPPROFILEREQUEST_FIELD_NUMBER: builtins.int
    PPROFALLOCSPROFILEREQUEST_FIELD_NUMBER: builtins.int
    PPROFBLOCKPROFILEREQUEST_FIELD_NUMBER: builtins.int
    PPROFMUTEXPROFILEREQUEST_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def pprofCpuProfileRequest(self) -> global___PprofCpuProfileRequest: ...
    @property
    def pprofHeapProfileRequest(self) -> global___PprofHeapProfileRequest: ...
    @property
    def pprofAllocsProfileRequest(self) -> global___PprofAllocsProfileRequest: ...
    @property
    def pprofBlockProfileRequest(self) -> global___PprofBlockProfileRequest: ...
    @property
    def pprofMutexProfileRequest(self) -> global___PprofMutexProfileRequest: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        pprofCpuProfileRequest: global___PprofCpuProfileRequest | None = ...,
        pprofHeapProfileRequest: global___PprofHeapProfileRequest | None = ...,
        pprofAllocsProfileRequest: global___PprofAllocsProfileRequest | None = ...,
        pprofBlockProfileRequest: global___PprofBlockProfileRequest | None = ...,
        pprofMutexProfileRequest: global___PprofMutexProfileRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body", b"body", "pprofAllocsProfileRequest", b"pprofAllocsProfileRequest", "pprofBlockProfileRequest", b"pprofBlockProfileRequest", "pprofCpuProfileRequest", b"pprofCpuProfileRequest", "pprofHeapProfileRequest", b"pprofHeapProfileRequest", "pprofMutexProfileRequest", b"pprofMutexProfileRequest"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "id", b"id", "pprofAllocsProfileRequest", b"pprofAllocsProfileRequest", "pprofBlockProfileRequest", b"pprofBlockProfileRequest", "pprofCpuProfileRequest", b"pprofCpuProfileRequest", "pprofHeapProfileRequest", b"pprofHeapProfileRequest", "pprofMutexProfileRequest", b"pprofMutexProfileRequest"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["body", b"body"]) -> typing_extensions.Literal["pprofCpuProfileRequest", "pprofHeapProfileRequest", "pprofAllocsProfileRequest", "pprofBlockProfileRequest", "pprofMutexProfileRequest"] | None: ...

global___PprofRequest = PprofRequest

@typing_extensions.final
class PprofAllocsProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEBUG_FIELD_NUMBER: builtins.int
    debug: builtins.bool
    def __init__(
        self,
        *,
        debug: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debug", b"debug"]) -> None: ...

global___PprofAllocsProfileRequest = PprofAllocsProfileRequest

@typing_extensions.final
class PprofBlockProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEBUG_FIELD_NUMBER: builtins.int
    debug: builtins.bool
    def __init__(
        self,
        *,
        debug: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debug", b"debug"]) -> None: ...

global___PprofBlockProfileRequest = PprofBlockProfileRequest

@typing_extensions.final
class PprofCpuProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECONDS_FIELD_NUMBER: builtins.int
    seconds: builtins.int
    def __init__(
        self,
        *,
        seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["seconds", b"seconds"]) -> None: ...

global___PprofCpuProfileRequest = PprofCpuProfileRequest

@typing_extensions.final
class PprofHeapProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GC_FIELD_NUMBER: builtins.int
    DEBUG_FIELD_NUMBER: builtins.int
    gc: builtins.bool
    debug: builtins.bool
    def __init__(
        self,
        *,
        gc: builtins.bool = ...,
        debug: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debug", b"debug", "gc", b"gc"]) -> None: ...

global___PprofHeapProfileRequest = PprofHeapProfileRequest

@typing_extensions.final
class PprofMutexProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEBUG_FIELD_NUMBER: builtins.int
    debug: builtins.bool
    def __init__(
        self,
        *,
        debug: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debug", b"debug"]) -> None: ...

global___PprofMutexProfileRequest = PprofMutexProfileRequest

@typing_extensions.final
class PprofResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROFILE_FIELD_NUMBER: builtins.int
    id: builtins.str
    profile: builtins.bytes
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        profile: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "profile", b"profile"]) -> None: ...

global___PprofResponse = PprofResponse

@typing_extensions.final
class PTYConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPEMODE_FIELD_NUMBER: builtins.int
    pipeMode: builtins.bool
    def __init__(
        self,
        *,
        pipeMode: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeMode", b"pipeMode"]) -> None: ...

global___PTYConfig = PTYConfig

@typing_extensions.final
class DebugMain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    READONLY_FIELD_NUMBER: builtins.int
    FILEPATH_FIELD_NUMBER: builtins.int
    DEBUGGERID_FIELD_NUMBER: builtins.int
    session: builtins.str
    readOnly: builtins.bool
    filePath: builtins.str
    debuggerId: builtins.str
    def __init__(
        self,
        *,
        session: builtins.str = ...,
        readOnly: builtins.bool = ...,
        filePath: builtins.str = ...,
        debuggerId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debuggerId", b"debuggerId", "filePath", b"filePath", "readOnly", b"readOnly", "session", b"session"]) -> None: ...

global___DebugMain = DebugMain

@typing_extensions.final
class DebugMainReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Protocol:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ProtocolEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DebugMainReply._Protocol.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DAP: DebugMainReply._Protocol.ValueType  # 0

    class Protocol(_Protocol, metaclass=_ProtocolEnumTypeWrapper): ...
    DAP: DebugMainReply.Protocol.ValueType  # 0

    JOINED_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    joined: builtins.bool
    protocol: global___DebugMainReply.Protocol.ValueType
    def __init__(
        self,
        *,
        joined: builtins.bool = ...,
        protocol: global___DebugMainReply.Protocol.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["joined", b"joined", "protocol", b"protocol"]) -> None: ...

global___DebugMainReply = DebugMainReply

@typing_extensions.final
class DebugState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    session: builtins.str
    state: global___State.ValueType
    def __init__(
        self,
        *,
        session: builtins.str = ...,
        state: global___State.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session", b"session", "state", b"state"]) -> None: ...

global___DebugState = DebugState

@typing_extensions.final
class DebugInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    ADAPTERINPUT_FIELD_NUMBER: builtins.int
    session: builtins.str
    input: builtins.str
    adapterInput: builtins.str
    def __init__(
        self,
        *,
        session: builtins.str = ...,
        input: builtins.str = ...,
        adapterInput: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["adapterInput", b"adapterInput", "input", b"input", "stream", b"stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["adapterInput", b"adapterInput", "input", b"input", "session", b"session", "stream", b"stream"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["stream", b"stream"]) -> typing_extensions.Literal["input", "adapterInput"] | None: ...

global___DebugInput = DebugInput

@typing_extensions.final
class DebugOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    ADAPTEROUTPUT_FIELD_NUMBER: builtins.int
    session: builtins.str
    output: builtins.str
    adapterOutput: builtins.str
    def __init__(
        self,
        *,
        session: builtins.str = ...,
        output: builtins.str = ...,
        adapterOutput: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["adapterOutput", b"adapterOutput", "output", b"output", "stream", b"stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["adapterOutput", b"adapterOutput", "output", b"output", "session", b"session", "stream", b"stream"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["stream", b"stream"]) -> typing_extensions.Literal["output", "adapterOutput"] | None: ...

global___DebugOutput = DebugOutput

@typing_extensions.final
class DebugStop(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    session: builtins.str
    def __init__(
        self,
        *,
        session: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session", b"session"]) -> None: ...

global___DebugStop = DebugStop

@typing_extensions.final
class DebugLeave(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    session: builtins.str
    def __init__(
        self,
        *,
        session: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session", b"session"]) -> None: ...

global___DebugLeave = DebugLeave

@typing_extensions.final
class DebugSessions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SessionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: global___State.ValueType
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___State.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def sessions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, global___State.ValueType]: ...
    def __init__(
        self,
        *,
        sessions: collections.abc.Mapping[builtins.str, global___State.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sessions", b"sessions"]) -> None: ...

global___DebugSessions = DebugSessions

@typing_extensions.final
class DotReplitGetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DotReplitGetRequest = DotReplitGetRequest

@typing_extensions.final
class DotReplitGetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOTREPLIT_FIELD_NUMBER: builtins.int
    @property
    def dotReplit(self) -> global___DotReplit: ...
    def __init__(
        self,
        *,
        dotReplit: global___DotReplit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dotReplit", b"dotReplit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dotReplit", b"dotReplit"]) -> None: ...

global___DotReplitGetResponse = DotReplitGetResponse

@typing_extensions.final
class RunConfigGetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RunConfigGetRequest = RunConfigGetRequest

@typing_extensions.final
class RunConfigGetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Run(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COMPILE_FIELD_NUMBER: builtins.int
        RUN_FIELD_NUMBER: builtins.int
        @property
        def compile(self) -> global___Exec: ...
        @property
        def run(self) -> global___Exec: ...
        def __init__(
            self,
            *,
            compile: global___Exec | None = ...,
            run: global___Exec | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["compile", b"compile", "run", b"run"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["compile", b"compile", "run", b"run"]) -> None: ...

    INTERP_FIELD_NUMBER: builtins.int
    RUN_FIELD_NUMBER: builtins.int
    @property
    def interp(self) -> global___DotReplitInterp: ...
    @property
    def run(self) -> global___RunConfigGetResponse.Run: ...
    def __init__(
        self,
        *,
        interp: global___DotReplitInterp | None = ...,
        run: global___RunConfigGetResponse.Run | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "interp", b"interp", "run", b"run"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "interp", b"interp", "run", b"run"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config", b"config"]) -> typing_extensions.Literal["interp", "run"] | None: ...

global___RunConfigGetResponse = RunConfigGetResponse

@typing_extensions.final
class DotReplitUpdateOp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OP_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    op: builtins.str
    path: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        op: builtins.str = ...,
        path: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["op", b"op", "path", b"path", "value", b"value"]) -> None: ...

global___DotReplitUpdateOp = DotReplitUpdateOp

@typing_extensions.final
class DotReplitUpdateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPS_FIELD_NUMBER: builtins.int
    @property
    def ops(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DotReplitUpdateOp]: ...
    def __init__(
        self,
        *,
        ops: collections.abc.Iterable[global___DotReplitUpdateOp] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ops", b"ops"]) -> None: ...

global___DotReplitUpdateRequest = DotReplitUpdateRequest

@typing_extensions.final
class DotReplitUpdateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DotReplitUpdateResponse = DotReplitUpdateResponse

@typing_extensions.final
class DebugAddBreakpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    OTVERSION_FIELD_NUMBER: builtins.int
    OTINDEX_FIELD_NUMBER: builtins.int
    SESSIONLOCAL_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    LOGMESSAGE_FIELD_NUMBER: builtins.int
    path: builtins.str
    otVersion: builtins.int
    otIndex: builtins.int
    sessionLocal: builtins.bool
    line: builtins.int
    logMessage: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        otVersion: builtins.int = ...,
        otIndex: builtins.int = ...,
        sessionLocal: builtins.bool = ...,
        line: builtins.int = ...,
        logMessage: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["line", b"line", "logMessage", b"logMessage", "otIndex", b"otIndex", "otVersion", b"otVersion", "path", b"path", "sessionLocal", b"sessionLocal"]) -> None: ...

global___DebugAddBreakpointRequest = DebugAddBreakpointRequest

@typing_extensions.final
class DebugUpdateBreakpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BREAKPOINTID_FIELD_NUMBER: builtins.int
    LOGMESSAGE_FIELD_NUMBER: builtins.int
    breakpointId: builtins.str
    logMessage: builtins.str
    def __init__(
        self,
        *,
        breakpointId: builtins.str = ...,
        logMessage: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["breakpointId", b"breakpointId", "logMessage", b"logMessage"]) -> None: ...

global___DebugUpdateBreakpointRequest = DebugUpdateBreakpointRequest

@typing_extensions.final
class DebugRemoveBreakpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BREAKPOINTID_FIELD_NUMBER: builtins.int
    breakpointId: builtins.str
    def __init__(
        self,
        *,
        breakpointId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["breakpointId", b"breakpointId"]) -> None: ...

global___DebugRemoveBreakpointRequest = DebugRemoveBreakpointRequest

@typing_extensions.final
class DebugBreakpointEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    ABSOLUTEPATH_FIELD_NUMBER: builtins.int
    BREAKPOINTS_FIELD_NUMBER: builtins.int
    path: builtins.str
    absolutePath: builtins.str
    @property
    def breakpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DebugBreakpoint]: ...
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        absolutePath: builtins.str = ...,
        breakpoints: collections.abc.Iterable[global___DebugBreakpoint] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["absolutePath", b"absolutePath", "breakpoints", b"breakpoints", "path", b"path"]) -> None: ...

global___DebugBreakpointEvent = DebugBreakpointEvent

@typing_extensions.final
class DebugBreakpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BREAKPOINTID_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    OTVERSION_FIELD_NUMBER: builtins.int
    OTINDEX_FIELD_NUMBER: builtins.int
    SESSIONLOCAL_FIELD_NUMBER: builtins.int
    LOGMESSAGE_FIELD_NUMBER: builtins.int
    breakpointId: builtins.str
    line: builtins.int
    otVersion: builtins.int
    otIndex: builtins.int
    sessionLocal: builtins.bool
    logMessage: builtins.str
    def __init__(
        self,
        *,
        breakpointId: builtins.str = ...,
        line: builtins.int = ...,
        otVersion: builtins.int = ...,
        otIndex: builtins.int = ...,
        sessionLocal: builtins.bool = ...,
        logMessage: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["breakpointId", b"breakpointId", "line", b"line", "logMessage", b"logMessage", "otIndex", b"otIndex", "otVersion", b"otVersion", "sessionLocal", b"sessionLocal"]) -> None: ...

global___DebugBreakpoint = DebugBreakpoint

@typing_extensions.final
class DotReplit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LanguagesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___DotReplitLanguage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___DotReplitLanguage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RUN_FIELD_NUMBER: builtins.int
    COMPILE_FIELD_NUMBER: builtins.int
    DEBUGGER_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    ONBOOT_FIELD_NUMBER: builtins.int
    PACKAGER_FIELD_NUMBER: builtins.int
    INTERPRETER_FIELD_NUMBER: builtins.int
    ENTRYPOINT_FIELD_NUMBER: builtins.int
    LANGUAGES_FIELD_NUMBER: builtins.int
    UNITTEST_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    NIX_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    HOSTING_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    GITHUBIMPORT_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    HINTSLIST_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    ORDEREDENV_FIELD_NUMBER: builtins.int
    REFRESHWEBVIEWONFILECHANGE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    EXTENSION_FIELD_NUMBER: builtins.int
    @property
    def run(self) -> global___Exec: ...
    @property
    def compile(self) -> global___Exec: ...
    @property
    def debugger(self) -> global___DebuggerConfig: ...
    language: builtins.str
    @property
    def onBoot(self) -> global___Exec: ...
    @property
    def packager(self) -> global___DotReplitPackager: ...
    @property
    def interpreter(self) -> global___DotReplitInterp: ...
    entrypoint: builtins.str
    @property
    def languages(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___DotReplitLanguage]: ...
    @property
    def unitTest(self) -> global___DotReplitUnitTest: ...
    @property
    def hidden(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def nix(self) -> global___NixConfig: ...
    audio: builtins.bool
    @property
    def hosting(self) -> global___HostingConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def gitHubImport(self) -> global___GitHubImportConfig: ...
    @property
    def auth(self) -> global___AuthConfig: ...
    @property
    def hintsList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DotReplitHint]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DotReplitPort]: ...
    @property
    def orderedEnv(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DotReplitEnvVar]: ...
    @property
    def refreshWebViewOnFileChange(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def deployment(self) -> global___DeploymentConfig: ...
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def extension(self) -> global___ExtensionConfig: ...
    def __init__(
        self,
        *,
        run: global___Exec | None = ...,
        compile: global___Exec | None = ...,
        debugger: global___DebuggerConfig | None = ...,
        language: builtins.str = ...,
        onBoot: global___Exec | None = ...,
        packager: global___DotReplitPackager | None = ...,
        interpreter: global___DotReplitInterp | None = ...,
        entrypoint: builtins.str = ...,
        languages: collections.abc.Mapping[builtins.str, global___DotReplitLanguage] | None = ...,
        unitTest: global___DotReplitUnitTest | None = ...,
        hidden: collections.abc.Iterable[builtins.str] | None = ...,
        nix: global___NixConfig | None = ...,
        audio: builtins.bool = ...,
        hosting: global___HostingConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        gitHubImport: global___GitHubImportConfig | None = ...,
        auth: global___AuthConfig | None = ...,
        hintsList: collections.abc.Iterable[global___DotReplitHint] | None = ...,
        ports: collections.abc.Iterable[global___DotReplitPort] | None = ...,
        orderedEnv: collections.abc.Iterable[global___DotReplitEnvVar] | None = ...,
        refreshWebViewOnFileChange: collections.abc.Iterable[builtins.str] | None = ...,
        deployment: global___DeploymentConfig | None = ...,
        modules: collections.abc.Iterable[builtins.str] | None = ...,
        extension: global___ExtensionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "compile", b"compile", "debugger", b"debugger", "deployment", b"deployment", "extension", b"extension", "gitHubImport", b"gitHubImport", "hosting", b"hosting", "interpreter", b"interpreter", "nix", b"nix", "onBoot", b"onBoot", "packager", b"packager", "run", b"run", "unitTest", b"unitTest"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "auth", b"auth", "compile", b"compile", "debugger", b"debugger", "deployment", b"deployment", "entrypoint", b"entrypoint", "env", b"env", "extension", b"extension", "gitHubImport", b"gitHubImport", "hidden", b"hidden", "hintsList", b"hintsList", "hosting", b"hosting", "interpreter", b"interpreter", "language", b"language", "languages", b"languages", "modules", b"modules", "nix", b"nix", "onBoot", b"onBoot", "orderedEnv", b"orderedEnv", "packager", b"packager", "ports", b"ports", "refreshWebViewOnFileChange", b"refreshWebViewOnFileChange", "run", b"run", "unitTest", b"unitTest"]) -> None: ...

global___DotReplit = DotReplit

@typing_extensions.final
class DotReplitEnvVar(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___DotReplitEnvVar = DotReplitEnvVar

@typing_extensions.final
class DotReplitPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCALPORT_FIELD_NUMBER: builtins.int
    EXTERNALPORT_FIELD_NUMBER: builtins.int
    localPort: builtins.int
    externalPort: builtins.int
    def __init__(
        self,
        *,
        localPort: builtins.int = ...,
        externalPort: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["externalPort", b"externalPort", "localPort", b"localPort"]) -> None: ...

global___DotReplitPort = DotReplitPort

@typing_extensions.final
class DotReplitHint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGEX_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    regex: builtins.str
    message: builtins.str
    def __init__(
        self,
        *,
        regex: builtins.str = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "regex", b"regex"]) -> None: ...

global___DotReplitHint = DotReplitHint

@typing_extensions.final
class GitHubImportConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUIREDFILES_FIELD_NUMBER: builtins.int
    @property
    def requiredFiles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        requiredFiles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["requiredFiles", b"requiredFiles"]) -> None: ...

global___GitHubImportConfig = GitHubImportConfig

@typing_extensions.final
class DeploymentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Target:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TargetEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DeploymentConfig._Target.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GCE: DeploymentConfig._Target.ValueType  # 0
        CLOUDRUN: DeploymentConfig._Target.ValueType  # 1
        STATIC: DeploymentConfig._Target.ValueType  # 2

    class Target(_Target, metaclass=_TargetEnumTypeWrapper): ...
    GCE: DeploymentConfig.Target.ValueType  # 0
    CLOUDRUN: DeploymentConfig.Target.ValueType  # 1
    STATIC: DeploymentConfig.Target.ValueType  # 2

    RUN_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    IGNOREPORTS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    PUBLICDIR_FIELD_NUMBER: builtins.int
    @property
    def run(self) -> global___Exec: ...
    @property
    def build(self) -> global___Exec: ...
    ignorePorts: builtins.bool
    target: global___DeploymentConfig.Target.ValueType
    publicDir: builtins.str
    def __init__(
        self,
        *,
        run: global___Exec | None = ...,
        build: global___Exec | None = ...,
        ignorePorts: builtins.bool = ...,
        target: global___DeploymentConfig.Target.ValueType = ...,
        publicDir: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build", b"build", "run", b"run"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "ignorePorts", b"ignorePorts", "publicDir", b"publicDir", "run", b"run", "target", b"target"]) -> None: ...

global___DeploymentConfig = DeploymentConfig

@typing_extensions.final
class ExtensionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISEXTENSION_FIELD_NUMBER: builtins.int
    EXTENSIONID_FIELD_NUMBER: builtins.int
    BUILDCOMMAND_FIELD_NUMBER: builtins.int
    OUTPUTDIRECTORY_FIELD_NUMBER: builtins.int
    isExtension: builtins.bool
    extensionID: builtins.str
    buildCommand: builtins.str
    outputDirectory: builtins.str
    def __init__(
        self,
        *,
        isExtension: builtins.bool = ...,
        extensionID: builtins.str = ...,
        buildCommand: builtins.str = ...,
        outputDirectory: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buildCommand", b"buildCommand", "extensionID", b"extensionID", "isExtension", b"isExtension", "outputDirectory", b"outputDirectory"]) -> None: ...

global___ExtensionConfig = ExtensionConfig

@typing_extensions.final
class NixConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_FIELD_NUMBER: builtins.int
    channel: builtins.str
    def __init__(
        self,
        *,
        channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel", b"channel"]) -> None: ...

global___NixConfig = NixConfig

@typing_extensions.final
class HostingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTE_FIELD_NUMBER: builtins.int
    DIRECTORY_FIELD_NUMBER: builtins.int
    route: builtins.str
    directory: builtins.str
    def __init__(
        self,
        *,
        route: builtins.str = ...,
        directory: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["directory", b"directory", "route", b"route"]) -> None: ...

global___HostingConfig = HostingConfig

@typing_extensions.final
class AuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGEENABLED_FIELD_NUMBER: builtins.int
    PAGETITLE_FIELD_NUMBER: builtins.int
    PAGEDESCRIPTION_FIELD_NUMBER: builtins.int
    PAGECOLOR_FIELD_NUMBER: builtins.int
    PAGEIMAGE_FIELD_NUMBER: builtins.int
    BUTTONENABLED_FIELD_NUMBER: builtins.int
    pageEnabled: builtins.bool
    pageTitle: builtins.str
    pageDescription: builtins.str
    pageColor: builtins.str
    pageImage: builtins.str
    buttonEnabled: builtins.bool
    def __init__(
        self,
        *,
        pageEnabled: builtins.bool = ...,
        pageTitle: builtins.str = ...,
        pageDescription: builtins.str = ...,
        pageColor: builtins.str = ...,
        pageImage: builtins.str = ...,
        buttonEnabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buttonEnabled", b"buttonEnabled", "pageColor", b"pageColor", "pageDescription", b"pageDescription", "pageEnabled", b"pageEnabled", "pageImage", b"pageImage", "pageTitle", b"pageTitle"]) -> None: ...

global___AuthConfig = AuthConfig

@typing_extensions.final
class DotReplitInterp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    PROMPT_FIELD_NUMBER: builtins.int
    @property
    def command(self) -> global___Exec: ...
    prompt: builtins.bytes
    def __init__(
        self,
        *,
        command: global___Exec | None = ...,
        prompt: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["command", b"command"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "prompt", b"prompt"]) -> None: ...

global___DotReplitInterp = DotReplitInterp

@typing_extensions.final
class DotReplitLanguage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATTERN_FIELD_NUMBER: builtins.int
    SYNTAX_FIELD_NUMBER: builtins.int
    LANGUAGESERVER_FIELD_NUMBER: builtins.int
    pattern: builtins.str
    syntax: builtins.str
    @property
    def languageServer(self) -> global___LanguageServerConfig: ...
    def __init__(
        self,
        *,
        pattern: builtins.str = ...,
        syntax: builtins.str = ...,
        languageServer: global___LanguageServerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["languageServer", b"languageServer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["languageServer", b"languageServer", "pattern", b"pattern", "syntax", b"syntax"]) -> None: ...

global___DotReplitLanguage = DotReplitLanguage

@typing_extensions.final
class LanguageServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STARTCOMMAND_FIELD_NUMBER: builtins.int
    CONFIGURATIONJSON_FIELD_NUMBER: builtins.int
    INITIALIZATIONOPTIONSJSON_FIELD_NUMBER: builtins.int
    @property
    def startCommand(self) -> global___Exec: ...
    configurationJson: builtins.str
    initializationOptionsJson: builtins.str
    def __init__(
        self,
        *,
        startCommand: global___Exec | None = ...,
        configurationJson: builtins.str = ...,
        initializationOptionsJson: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["startCommand", b"startCommand"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configurationJson", b"configurationJson", "initializationOptionsJson", b"initializationOptionsJson", "startCommand", b"startCommand"]) -> None: ...

global___LanguageServerConfig = LanguageServerConfig

@typing_extensions.final
class DotReplitPackager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AFTERINSTALL_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    IGNOREDPATHS_FIELD_NUMBER: builtins.int
    IGNOREDPACKAGES_FIELD_NUMBER: builtins.int
    @property
    def afterInstall(self) -> global___Exec: ...
    language: builtins.str
    @property
    def features(self) -> global___DotReplitPackagerFeatures: ...
    @property
    def env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def ignoredPaths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ignoredPackages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        afterInstall: global___Exec | None = ...,
        language: builtins.str = ...,
        features: global___DotReplitPackagerFeatures | None = ...,
        env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ignoredPaths: collections.abc.Iterable[builtins.str] | None = ...,
        ignoredPackages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["afterInstall", b"afterInstall", "features", b"features"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["afterInstall", b"afterInstall", "env", b"env", "features", b"features", "ignoredPackages", b"ignoredPackages", "ignoredPaths", b"ignoredPaths", "language", b"language"]) -> None: ...

global___DotReplitPackager = DotReplitPackager

@typing_extensions.final
class DotReplitPackagerFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGESEARCH_FIELD_NUMBER: builtins.int
    GUESSIMPORTS_FIELD_NUMBER: builtins.int
    ENABLEDFORHOSTING_FIELD_NUMBER: builtins.int
    packageSearch: builtins.bool
    guessImports: builtins.bool
    enabledForHosting: builtins.bool
    def __init__(
        self,
        *,
        packageSearch: builtins.bool = ...,
        guessImports: builtins.bool = ...,
        enabledForHosting: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabledForHosting", b"enabledForHosting", "guessImports", b"guessImports", "packageSearch", b"packageSearch"]) -> None: ...

global___DotReplitPackagerFeatures = DotReplitPackagerFeatures

@typing_extensions.final
class DotReplitUnitTest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    language: builtins.str
    def __init__(
        self,
        *,
        language: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["language", b"language"]) -> None: ...

global___DotReplitUnitTest = DotReplitUnitTest

@typing_extensions.final
class DebuggerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPORT_FIELD_NUMBER: builtins.int
    COMPILE_FIELD_NUMBER: builtins.int
    INTERACTIVE_FIELD_NUMBER: builtins.int
    TIMETRAVEL_FIELD_NUMBER: builtins.int
    DAPTRANSPORT_FIELD_NUMBER: builtins.int
    DAPCONNECTTIMEOUT_FIELD_NUMBER: builtins.int
    DAPINTEGRATEDADAPTER_FIELD_NUMBER: builtins.int
    DAPSTARTCOMMAND_FIELD_NUMBER: builtins.int
    DAPINITIALIZEMESSAGE_FIELD_NUMBER: builtins.int
    DAPLAUNCHMESSAGE_FIELD_NUMBER: builtins.int
    support: builtins.bool
    @property
    def compile(self) -> global___CompileConfig: ...
    @property
    def interactive(self) -> global___DapConfig: ...
    @property
    def timeTravel(self) -> global___TimeTravelConfig: ...
    dapTransport: builtins.str
    dapConnectTimeout: builtins.int
    @property
    def dapIntegratedAdapter(self) -> global___DapIntegratedAdapterConfig: ...
    @property
    def dapStartCommand(self) -> global___Exec: ...
    @property
    def dapInitializeMessage(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def dapLaunchMessage(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        support: builtins.bool = ...,
        compile: global___CompileConfig | None = ...,
        interactive: global___DapConfig | None = ...,
        timeTravel: global___TimeTravelConfig | None = ...,
        dapTransport: builtins.str = ...,
        dapConnectTimeout: builtins.int = ...,
        dapIntegratedAdapter: global___DapIntegratedAdapterConfig | None = ...,
        dapStartCommand: global___Exec | None = ...,
        dapInitializeMessage: google.protobuf.struct_pb2.Struct | None = ...,
        dapLaunchMessage: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compile", b"compile", "dapInitializeMessage", b"dapInitializeMessage", "dapIntegratedAdapter", b"dapIntegratedAdapter", "dapLaunchMessage", b"dapLaunchMessage", "dapStartCommand", b"dapStartCommand", "interactive", b"interactive", "timeTravel", b"timeTravel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compile", b"compile", "dapConnectTimeout", b"dapConnectTimeout", "dapInitializeMessage", b"dapInitializeMessage", "dapIntegratedAdapter", b"dapIntegratedAdapter", "dapLaunchMessage", b"dapLaunchMessage", "dapStartCommand", b"dapStartCommand", "dapTransport", b"dapTransport", "interactive", b"interactive", "support", b"support", "timeTravel", b"timeTravel"]) -> None: ...

global___DebuggerConfig = DebuggerConfig

@typing_extensions.final
class CompileConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    ONLYMAIN_FIELD_NUMBER: builtins.int
    NOFILEARGS_FIELD_NUMBER: builtins.int
    @property
    def command(self) -> global___Exec: ...
    onlyMain: builtins.bool
    noFileArgs: builtins.bool
    def __init__(
        self,
        *,
        command: global___Exec | None = ...,
        onlyMain: builtins.bool = ...,
        noFileArgs: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["command", b"command"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "noFileArgs", b"noFileArgs", "onlyMain", b"onlyMain"]) -> None: ...

global___CompileConfig = CompileConfig

@typing_extensions.final
class DapConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSPORT_FIELD_NUMBER: builtins.int
    CONNECTTIMEOUT_FIELD_NUMBER: builtins.int
    INTEGRATEDADAPTER_FIELD_NUMBER: builtins.int
    STARTCOMMAND_FIELD_NUMBER: builtins.int
    INITIALIZEMESSAGE_FIELD_NUMBER: builtins.int
    LAUNCHMESSAGE_FIELD_NUMBER: builtins.int
    transport: builtins.str
    connectTimeout: builtins.int
    @property
    def integratedAdapter(self) -> global___DapIntegratedAdapterConfig: ...
    @property
    def startCommand(self) -> global___Exec: ...
    @property
    def initializeMessage(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def launchMessage(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        transport: builtins.str = ...,
        connectTimeout: builtins.int = ...,
        integratedAdapter: global___DapIntegratedAdapterConfig | None = ...,
        startCommand: global___Exec | None = ...,
        initializeMessage: google.protobuf.struct_pb2.Struct | None = ...,
        launchMessage: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["initializeMessage", b"initializeMessage", "integratedAdapter", b"integratedAdapter", "launchMessage", b"launchMessage", "startCommand", b"startCommand"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connectTimeout", b"connectTimeout", "initializeMessage", b"initializeMessage", "integratedAdapter", b"integratedAdapter", "launchMessage", b"launchMessage", "startCommand", b"startCommand", "transport", b"transport"]) -> None: ...

global___DapConfig = DapConfig

@typing_extensions.final
class TimeTravelConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_FIELD_NUMBER: builtins.int
    DEBUG_FIELD_NUMBER: builtins.int
    @property
    def record(self) -> global___Exec: ...
    @property
    def debug(self) -> global___DapConfig: ...
    def __init__(
        self,
        *,
        record: global___Exec | None = ...,
        debug: global___DapConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["debug", b"debug", "record", b"record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["debug", b"debug", "record", b"record"]) -> None: ...

global___TimeTravelConfig = TimeTravelConfig

@typing_extensions.final
class DapIntegratedAdapterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAPTCPADDRESS_FIELD_NUMBER: builtins.int
    dapTcpAddress: builtins.str
    def __init__(
        self,
        *,
        dapTcpAddress: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dapTcpAddress", b"dapTcpAddress"]) -> None: ...

global___DapIntegratedAdapterConfig = DapIntegratedAdapterConfig

@typing_extensions.final
class ProxyGoingAway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ProxyGoingAway = ProxyGoingAway

@typing_extensions.final
class FirewallDenied(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FirewallDenied = FirewallDenied

@typing_extensions.final
class ReplLogMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    REPLID_FIELD_NUMBER: builtins.int
    LOGLINE_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    replId: builtins.str
    logLine: builtins.str
    userName: builtins.str
    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        replId: builtins.str = ...,
        logLine: builtins.str = ...,
        userName: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["logLine", b"logLine", "replId", b"replId", "timestamp", b"timestamp", "userName", b"userName"]) -> None: ...

global___ReplLogMessage = ReplLogMessage

@typing_extensions.final
class UserEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTNAME_FIELD_NUMBER: builtins.int
    EVENTDATA_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    eventName: builtins.str
    @property
    def eventData(self) -> google.protobuf.struct_pb2.Struct: ...
    version: builtins.int
    def __init__(
        self,
        *,
        eventName: builtins.str = ...,
        eventData: google.protobuf.struct_pb2.Struct | None = ...,
        version: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["eventData", b"eventData"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["eventData", b"eventData", "eventName", b"eventName", "version", b"version"]) -> None: ...

global___UserEvent = UserEvent

@typing_extensions.final
class NixModulesGetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NixModulesGetRequest = NixModulesGetRequest

@typing_extensions.final
class NixModulesGetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULES_FIELD_NUMBER: builtins.int
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NixModule]: ...
    def __init__(
        self,
        *,
        modules: collections.abc.Iterable[global___NixModule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["modules", b"modules"]) -> None: ...

global___NixModulesGetResponse = NixModulesGetResponse

@typing_extensions.final
class NixModule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RUNNERS_FIELD_NUMBER: builtins.int
    DEBUGGERS_FIELD_NUMBER: builtins.int
    PACKAGERS_FIELD_NUMBER: builtins.int
    LANGUAGESERVERS_FIELD_NUMBER: builtins.int
    id: builtins.str
    version: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def runners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunOption]: ...
    @property
    def debuggers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DebuggerOption]: ...
    @property
    def packagers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PackagerOption]: ...
    @property
    def languageServers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LanguageServerOption]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        runners: collections.abc.Iterable[global___RunOption] | None = ...,
        debuggers: collections.abc.Iterable[global___DebuggerOption] | None = ...,
        packagers: collections.abc.Iterable[global___PackagerOption] | None = ...,
        languageServers: collections.abc.Iterable[global___LanguageServerOption] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debuggers", b"debuggers", "description", b"description", "id", b"id", "languageServers", b"languageServers", "name", b"name", "packagers", b"packagers", "runners", b"runners", "version", b"version"]) -> None: ...

global___NixModule = NixModule

@typing_extensions.final
class NixModulesChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULES_FIELD_NUMBER: builtins.int
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NixModule]: ...
    def __init__(
        self,
        *,
        modules: collections.abc.Iterable[global___NixModule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["modules", b"modules"]) -> None: ...

global___NixModulesChanged = NixModulesChanged

@typing_extensions.final
class NixModulesBuildRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NixModulesBuildRequest = NixModulesBuildRequest

@typing_extensions.final
class ToolchainGetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ToolchainGetRequest = ToolchainGetRequest

@typing_extensions.final
class ToolchainConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTRYPOINT_FIELD_NUMBER: builtins.int
    RUNS_FIELD_NUMBER: builtins.int
    DEBUGGERS_FIELD_NUMBER: builtins.int
    LANGUAGESERVERS_FIELD_NUMBER: builtins.int
    PACKAGERS_FIELD_NUMBER: builtins.int
    entrypoint: builtins.str
    @property
    def runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunOption]: ...
    @property
    def debuggers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DebuggerOption]: ...
    @property
    def languageServers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LanguageServerOption]: ...
    @property
    def packagers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PackagerOption]: ...
    def __init__(
        self,
        *,
        entrypoint: builtins.str = ...,
        runs: collections.abc.Iterable[global___RunOption] | None = ...,
        debuggers: collections.abc.Iterable[global___DebuggerOption] | None = ...,
        languageServers: collections.abc.Iterable[global___LanguageServerOption] | None = ...,
        packagers: collections.abc.Iterable[global___PackagerOption] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debuggers", b"debuggers", "entrypoint", b"entrypoint", "languageServers", b"languageServers", "packagers", b"packagers", "runs", b"runs"]) -> None: ...

global___ToolchainConfigs = ToolchainConfigs

@typing_extensions.final
class ToolchainGetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGS_FIELD_NUMBER: builtins.int
    @property
    def configs(self) -> global___ToolchainConfigs: ...
    def __init__(
        self,
        *,
        configs: global___ToolchainConfigs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configs", b"configs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configs", b"configs"]) -> None: ...

global___ToolchainGetResponse = ToolchainGetResponse

@typing_extensions.final
class ToolchainChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGS_FIELD_NUMBER: builtins.int
    @property
    def configs(self) -> global___ToolchainConfigs: ...
    def __init__(
        self,
        *,
        configs: global___ToolchainConfigs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configs", b"configs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configs", b"configs"]) -> None: ...

global___ToolchainChanged = ToolchainChanged

@typing_extensions.final
class RunOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FILEPARAM_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    FILETYPEATTRS_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    fileParam: builtins.bool
    language: builtins.str
    @property
    def fileTypeAttrs(self) -> global___FileTypeAttrs: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        fileParam: builtins.bool = ...,
        language: builtins.str = ...,
        fileTypeAttrs: global___FileTypeAttrs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fileTypeAttrs", b"fileTypeAttrs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fileParam", b"fileParam", "fileTypeAttrs", b"fileTypeAttrs", "id", b"id", "language", b"language", "name", b"name"]) -> None: ...

global___RunOption = RunOption

@typing_extensions.final
class DebuggerOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FILEPARAM_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    FILETYPEATTRS_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    fileParam: builtins.bool
    language: builtins.str
    @property
    def fileTypeAttrs(self) -> global___FileTypeAttrs: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        fileParam: builtins.bool = ...,
        language: builtins.str = ...,
        fileTypeAttrs: global___FileTypeAttrs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fileTypeAttrs", b"fileTypeAttrs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fileParam", b"fileParam", "fileTypeAttrs", b"fileTypeAttrs", "id", b"id", "language", b"language", "name", b"name"]) -> None: ...

global___DebuggerOption = DebuggerOption

@typing_extensions.final
class LanguageServerOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    FILETYPEATTRS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    language: builtins.str
    @property
    def fileTypeAttrs(self) -> global___FileTypeAttrs: ...
    @property
    def config(self) -> global___LanguageServerConfig: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        language: builtins.str = ...,
        fileTypeAttrs: global___FileTypeAttrs | None = ...,
        config: global___LanguageServerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "fileTypeAttrs", b"fileTypeAttrs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "fileTypeAttrs", b"fileTypeAttrs", "id", b"id", "language", b"language", "name", b"name"]) -> None: ...

global___LanguageServerOption = LanguageServerOption

@typing_extensions.final
class FileTypeAttrs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTENSIONS_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    FILEPATTERN_FIELD_NUMBER: builtins.int
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    filePattern: builtins.str
    def __init__(
        self,
        *,
        extensions: collections.abc.Iterable[builtins.str] | None = ...,
        files: collections.abc.Iterable[builtins.str] | None = ...,
        filePattern: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extensions", b"extensions", "filePattern", b"filePattern", "files", b"files"]) -> None: ...

global___FileTypeAttrs = FileTypeAttrs

@typing_extensions.final
class PackagerOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    PACKAGERFILES_FIELD_NUMBER: builtins.int
    ENABLEDFORHOSTING_FIELD_NUMBER: builtins.int
    PACKAGESEARCH_FIELD_NUMBER: builtins.int
    GUESSIMPORTS_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    language: builtins.str
    @property
    def packagerFiles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enabledForHosting: builtins.bool
    packageSearch: builtins.bool
    guessImports: builtins.bool
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        language: builtins.str = ...,
        packagerFiles: collections.abc.Iterable[builtins.str] | None = ...,
        enabledForHosting: builtins.bool = ...,
        packageSearch: builtins.bool = ...,
        guessImports: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabledForHosting", b"enabledForHosting", "guessImports", b"guessImports", "id", b"id", "language", b"language", "name", b"name", "packageSearch", b"packageSearch", "packagerFiles", b"packagerFiles"]) -> None: ...

global___PackagerOption = PackagerOption

@typing_extensions.final
class ReplDomainDoubleDash(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    SUFFIX_FIELD_NUMBER: builtins.int
    user: builtins.str
    slug: builtins.str
    suffix: builtins.str
    def __init__(
        self,
        *,
        user: builtins.str = ...,
        slug: builtins.str = ...,
        suffix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["slug", b"slug", "suffix", b"suffix", "user", b"user"]) -> None: ...

global___ReplDomainDoubleDash = ReplDomainDoubleDash

@typing_extensions.final
class ReplDomainDots(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    SUFFIX_FIELD_NUMBER: builtins.int
    user: builtins.str
    slug: builtins.str
    suffix: builtins.str
    def __init__(
        self,
        *,
        user: builtins.str = ...,
        slug: builtins.str = ...,
        suffix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["slug", b"slug", "suffix", b"suffix", "user", b"user"]) -> None: ...

global___ReplDomainDots = ReplDomainDots

@typing_extensions.final
class ReplDomainSingleDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    SUFFIX_FIELD_NUMBER: builtins.int
    user: builtins.str
    suffix: builtins.str
    def __init__(
        self,
        *,
        user: builtins.str = ...,
        suffix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["suffix", b"suffix", "user", b"user"]) -> None: ...

global___ReplDomainSingleDomain = ReplDomainSingleDomain

@typing_extensions.final
class ReplDomainId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SUFFIX_FIELD_NUMBER: builtins.int
    id: builtins.str
    suffix: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        suffix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "suffix", b"suffix"]) -> None: ...

global___ReplDomainId = ReplDomainId

@typing_extensions.final
class ReplDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOM_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DOUBLEDASH_FIELD_NUMBER: builtins.int
    DOTS_FIELD_NUMBER: builtins.int
    SINGLEDOMAIN_FIELD_NUMBER: builtins.int
    custom: builtins.str
    @property
    def id(self) -> global___ReplDomainId: ...
    @property
    def doubleDash(self) -> global___ReplDomainDoubleDash: ...
    @property
    def dots(self) -> global___ReplDomainDots: ...
    @property
    def singleDomain(self) -> global___ReplDomainSingleDomain: ...
    def __init__(
        self,
        *,
        custom: builtins.str = ...,
        id: global___ReplDomainId | None = ...,
        doubleDash: global___ReplDomainDoubleDash | None = ...,
        dots: global___ReplDomainDots | None = ...,
        singleDomain: global___ReplDomainSingleDomain | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom", b"custom", "dots", b"dots", "doubleDash", b"doubleDash", "id", b"id", "kind", b"kind", "singleDomain", b"singleDomain"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom", b"custom", "dots", b"dots", "doubleDash", b"doubleDash", "id", b"id", "kind", b"kind", "singleDomain", b"singleDomain"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["kind", b"kind"]) -> typing_extensions.Literal["custom", "id", "doubleDash", "dots", "singleDomain"] | None: ...

global___ReplDomain = ReplDomain

@typing_extensions.final
class ReplToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _WireFormat:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WireFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ReplToken._WireFormat.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PROTOBUF: ReplToken._WireFormat.ValueType  # 0
        JSON: ReplToken._WireFormat.ValueType  # 1

    class WireFormat(_WireFormat, metaclass=_WireFormatEnumTypeWrapper): ...
    PROTOBUF: ReplToken.WireFormat.ValueType  # 0
    JSON: ReplToken.WireFormat.ValueType  # 1

    @typing_extensions.final
    class ClassroomMetadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        LANGUAGE_FIELD_NUMBER: builtins.int
        id: builtins.str
        language: builtins.str
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            language: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "language", b"language"]) -> None: ...

    @typing_extensions.final
    class ReplID(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        SOURCEREPL_FIELD_NUMBER: builtins.int
        id: builtins.str
        sourceRepl: builtins.str
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            sourceRepl: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "sourceRepl", b"sourceRepl"]) -> None: ...

    @typing_extensions.final
    class Presenced(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BEARERID_FIELD_NUMBER: builtins.int
        BEARERNAME_FIELD_NUMBER: builtins.int
        bearerID: builtins.int
        bearerName: builtins.str
        def __init__(
            self,
            *,
            bearerID: builtins.int = ...,
            bearerName: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["bearerID", b"bearerID", "bearerName", b"bearerName"]) -> None: ...

    IAT_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    SALT_FIELD_NUMBER: builtins.int
    CLUSTER_FIELD_NUMBER: builtins.int
    PERSISTENCE_FIELD_NUMBER: builtins.int
    RESOURCELIMITS_FIELD_NUMBER: builtins.int
    INTERACTIVERESOURCELIMITS_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    PRESENCED_FIELD_NUMBER: builtins.int
    FLAGS_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    BUILDINFO_FIELD_NUMBER: builtins.int
    REPL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CLASSROOM_FIELD_NUMBER: builtins.int
    @property
    def iat(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def exp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    salt: builtins.str
    cluster: builtins.str
    persistence: global___repl.Persistence.ValueType
    @property
    def resourceLimits(self) -> global___repl.ResourceLimits: ...
    @property
    def interactiveResourceLimits(self) -> global___repl.ResourceLimits: ...
    format: global___ReplToken.WireFormat.ValueType
    @property
    def presenced(self) -> global___ReplToken.Presenced: ...
    @property
    def flags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def permissions(self) -> global___repl.Permissions: ...
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___features.Feature]: ...
    @property
    def buildInfo(self) -> global___repl.BuildInfo: ...
    @property
    def repl(self) -> global___repl.Repl: ...
    @property
    def id(self) -> global___ReplToken.ReplID: ...
    @property
    def classroom(self) -> global___ReplToken.ClassroomMetadata: ...
    def __init__(
        self,
        *,
        iat: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        exp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        salt: builtins.str = ...,
        cluster: builtins.str = ...,
        persistence: global___repl.Persistence.ValueType = ...,
        resourceLimits: global___repl.ResourceLimits | None = ...,
        interactiveResourceLimits: global___repl.ResourceLimits | None = ...,
        format: global___ReplToken.WireFormat.ValueType = ...,
        presenced: global___ReplToken.Presenced | None = ...,
        flags: collections.abc.Iterable[builtins.str] | None = ...,
        permissions: global___repl.Permissions | None = ...,
        features: collections.abc.Iterable[global___features.Feature] | None = ...,
        buildInfo: global___repl.BuildInfo | None = ...,
        repl: global___repl.Repl | None = ...,
        id: global___ReplToken.ReplID | None = ...,
        classroom: global___ReplToken.ClassroomMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buildInfo", b"buildInfo", "classroom", b"classroom", "exp", b"exp", "iat", b"iat", "id", b"id", "interactiveResourceLimits", b"interactiveResourceLimits", "metadata", b"metadata", "permissions", b"permissions", "presenced", b"presenced", "repl", b"repl", "resourceLimits", b"resourceLimits"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["buildInfo", b"buildInfo", "classroom", b"classroom", "cluster", b"cluster", "exp", b"exp", "features", b"features", "flags", b"flags", "format", b"format", "iat", b"iat", "id", b"id", "interactiveResourceLimits", b"interactiveResourceLimits", "metadata", b"metadata", "permissions", b"permissions", "persistence", b"persistence", "presenced", b"presenced", "repl", b"repl", "resourceLimits", b"resourceLimits", "salt", b"salt"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["metadata", b"metadata"]) -> typing_extensions.Literal["repl", "id", "classroom"] | None: ...

global___ReplToken = ReplToken

@typing_extensions.final
class TLSCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    CERT_FIELD_NUMBER: builtins.int
    domain: builtins.str
    cert: builtins.bytes
    def __init__(
        self,
        *,
        domain: builtins.str = ...,
        cert: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert", b"cert", "domain", b"domain"]) -> None: ...

global___TLSCertificate = TLSCertificate

@typing_extensions.final
class ReplTransfer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPL_FIELD_NUMBER: builtins.int
    REPLLIMITS_FIELD_NUMBER: builtins.int
    USERLIMITS_FIELD_NUMBER: builtins.int
    CUSTOMDOMAINS_FIELD_NUMBER: builtins.int
    CERTIFICATES_FIELD_NUMBER: builtins.int
    FLAGS_FIELD_NUMBER: builtins.int
    @property
    def repl(self) -> global___repl.Repl: ...
    @property
    def replLimits(self) -> global___repl.ResourceLimits: ...
    @property
    def userLimits(self) -> global___repl.ResourceLimits: ...
    @property
    def customDomains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TLSCertificate]: ...
    @property
    def flags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        repl: global___repl.Repl | None = ...,
        replLimits: global___repl.ResourceLimits | None = ...,
        userLimits: global___repl.ResourceLimits | None = ...,
        customDomains: collections.abc.Iterable[builtins.str] | None = ...,
        certificates: collections.abc.Iterable[global___TLSCertificate] | None = ...,
        flags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repl", b"repl", "replLimits", b"replLimits", "userLimits", b"userLimits"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificates", b"certificates", "customDomains", b"customDomains", "flags", b"flags", "repl", b"repl", "replLimits", b"replLimits", "userLimits", b"userLimits"]) -> None: ...

global___ReplTransfer = ReplTransfer

@typing_extensions.final
class AllowReplRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLTRANSFER_FIELD_NUMBER: builtins.int
    @property
    def replTransfer(self) -> global___ReplTransfer: ...
    def __init__(
        self,
        *,
        replTransfer: global___ReplTransfer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["replTransfer", b"replTransfer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["replTransfer", b"replTransfer"]) -> None: ...

global___AllowReplRequest = AllowReplRequest

@typing_extensions.final
class ClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CONMANURL_FIELD_NUMBER: builtins.int
    GURL_FIELD_NUMBER: builtins.int
    PROXY_FIELD_NUMBER: builtins.int
    CONTINENT_FIELD_NUMBER: builtins.int
    id: builtins.str
    conmanURL: builtins.str
    gurl: builtins.str
    proxy: builtins.str
    continent: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        conmanURL: builtins.str = ...,
        gurl: builtins.str = ...,
        proxy: builtins.str = ...,
        continent: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["conmanURL", b"conmanURL", "continent", b"continent", "gurl", b"gurl", "id", b"id", "proxy", b"proxy"]) -> None: ...

global___ClusterMetadata = ClusterMetadata

@typing_extensions.final
class EvictReplRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERMETADATA_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    @property
    def clusterMetadata(self) -> global___ClusterMetadata: ...
    token: builtins.str
    user: builtins.str
    slug: builtins.str
    def __init__(
        self,
        *,
        clusterMetadata: global___ClusterMetadata | None = ...,
        token: builtins.str = ...,
        user: builtins.str = ...,
        slug: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["clusterMetadata", b"clusterMetadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["clusterMetadata", b"clusterMetadata", "slug", b"slug", "token", b"token", "user", b"user"]) -> None: ...

global___EvictReplRequest = EvictReplRequest

@typing_extensions.final
class EvictReplResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLTRANSFER_FIELD_NUMBER: builtins.int
    @property
    def replTransfer(self) -> global___ReplTransfer: ...
    def __init__(
        self,
        *,
        replTransfer: global___ReplTransfer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["replTransfer", b"replTransfer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["replTransfer", b"replTransfer"]) -> None: ...

global___EvictReplResponse = EvictReplResponse

@typing_extensions.final
class GovalSigningAuthority(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    KEYID_FIELD_NUMBER: builtins.int
    SIGNEDCERT_FIELD_NUMBER: builtins.int
    version: global___TokenVersion.ValueType
    issuer: builtins.str
    keyId: builtins.str
    signedCert: builtins.str
    def __init__(
        self,
        *,
        version: global___TokenVersion.ValueType = ...,
        issuer: builtins.str = ...,
        keyId: builtins.str = ...,
        signedCert: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cert", b"cert", "keyId", b"keyId", "signedCert", b"signedCert"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert", b"cert", "issuer", b"issuer", "keyId", b"keyId", "signedCert", b"signedCert", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cert", b"cert"]) -> typing_extensions.Literal["keyId", "signedCert"] | None: ...

global___GovalSigningAuthority = GovalSigningAuthority

@typing_extensions.final
class CertificateClaim(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    CLUSTER_FIELD_NUMBER: builtins.int
    FLAG_FIELD_NUMBER: builtins.int
    replid: builtins.str
    user: builtins.str
    cluster: builtins.str
    flag: global___FlagClaim.ValueType
    def __init__(
        self,
        *,
        replid: builtins.str = ...,
        user: builtins.str = ...,
        cluster: builtins.str = ...,
        flag: global___FlagClaim.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["claim", b"claim", "cluster", b"cluster", "flag", b"flag", "replid", b"replid", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["claim", b"claim", "cluster", b"cluster", "flag", b"flag", "replid", b"replid", "user", b"user"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["claim", b"claim"]) -> typing_extensions.Literal["replid", "user", "cluster", "flag"] | None: ...

global___CertificateClaim = CertificateClaim

@typing_extensions.final
class GovalCert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IAT_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    CLAIMS_FIELD_NUMBER: builtins.int
    PUBLICKEY_FIELD_NUMBER: builtins.int
    @property
    def iat(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def exp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def claims(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CertificateClaim]: ...
    publicKey: builtins.str
    def __init__(
        self,
        *,
        iat: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        exp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        claims: collections.abc.Iterable[global___CertificateClaim] | None = ...,
        publicKey: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exp", b"exp", "iat", b"iat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["claims", b"claims", "exp", b"exp", "iat", b"iat", "publicKey", b"publicKey"]) -> None: ...

global___GovalCert = GovalCert

@typing_extensions.final
class GovalToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IAT_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    REPLID_FIELD_NUMBER: builtins.int
    REPLTOKEN_FIELD_NUMBER: builtins.int
    REPLIDENTITY_FIELD_NUMBER: builtins.int
    @property
    def iat(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def exp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    replid: builtins.str
    @property
    def replToken(self) -> global___ReplToken: ...
    @property
    def replIdentity(self) -> global___GovalReplIdentity: ...
    def __init__(
        self,
        *,
        iat: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        exp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        replid: builtins.str = ...,
        replToken: global___ReplToken | None = ...,
        replIdentity: global___GovalReplIdentity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["Token", b"Token", "exp", b"exp", "iat", b"iat", "replIdentity", b"replIdentity", "replToken", b"replToken"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Token", b"Token", "exp", b"exp", "iat", b"iat", "replIdentity", b"replIdentity", "replToken", b"replToken", "replid", b"replid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["Token", b"Token"]) -> typing_extensions.Literal["replToken", "replIdentity"] | None: ...

global___GovalToken = GovalToken

@typing_extensions.final
class GovalReplIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    AUD_FIELD_NUMBER: builtins.int
    EPHEMERAL_FIELD_NUMBER: builtins.int
    ORIGINREPLID_FIELD_NUMBER: builtins.int
    USERID_FIELD_NUMBER: builtins.int
    BUILDINFO_FIELD_NUMBER: builtins.int
    replid: builtins.str
    user: builtins.str
    slug: builtins.str
    aud: builtins.str
    ephemeral: builtins.bool
    originReplid: builtins.str
    userId: builtins.int
    @property
    def buildInfo(self) -> global___repl.BuildInfo: ...
    def __init__(
        self,
        *,
        replid: builtins.str = ...,
        user: builtins.str = ...,
        slug: builtins.str = ...,
        aud: builtins.str = ...,
        ephemeral: builtins.bool = ...,
        originReplid: builtins.str = ...,
        userId: builtins.int = ...,
        buildInfo: global___repl.BuildInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buildInfo", b"buildInfo"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aud", b"aud", "buildInfo", b"buildInfo", "ephemeral", b"ephemeral", "originReplid", b"originReplid", "replid", b"replid", "slug", b"slug", "user", b"user", "userId", b"userId"]) -> None: ...

global___GovalReplIdentity = GovalReplIdentity

@typing_extensions.final
class lore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LoreCommand(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CLUSTERTRANSFER_FIELD_NUMBER: builtins.int
        SOFTTAKEDOWN_FIELD_NUMBER: builtins.int
        TAKEDOWN_FIELD_NUMBER: builtins.int
        GOVALCOMMAND_FIELD_NUMBER: builtins.int
        MULTIGOVALCOMMAND_FIELD_NUMBER: builtins.int
        RESTORE_FIELD_NUMBER: builtins.int
        @property
        def clusterTransfer(self) -> global___lore.ClusterTransfer: ...
        @property
        def softTakedown(self) -> global___lore.SoftTakedown: ...
        @property
        def takedown(self) -> global___lore.Takedown: ...
        @property
        def govalCommand(self) -> global___lore.GovalCommand: ...
        @property
        def multiGovalCommand(self) -> global___lore.MultiGovalCommand: ...
        @property
        def restore(self) -> global___lore.Restore: ...
        def __init__(
            self,
            *,
            clusterTransfer: global___lore.ClusterTransfer | None = ...,
            softTakedown: global___lore.SoftTakedown | None = ...,
            takedown: global___lore.Takedown | None = ...,
            govalCommand: global___lore.GovalCommand | None = ...,
            multiGovalCommand: global___lore.MultiGovalCommand | None = ...,
            restore: global___lore.Restore | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["clusterTransfer", b"clusterTransfer", "command", b"command", "govalCommand", b"govalCommand", "multiGovalCommand", b"multiGovalCommand", "restore", b"restore", "softTakedown", b"softTakedown", "takedown", b"takedown"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["clusterTransfer", b"clusterTransfer", "command", b"command", "govalCommand", b"govalCommand", "multiGovalCommand", b"multiGovalCommand", "restore", b"restore", "softTakedown", b"softTakedown", "takedown", b"takedown"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["command", b"command"]) -> typing_extensions.Literal["clusterTransfer", "softTakedown", "takedown", "govalCommand", "multiGovalCommand", "restore"] | None: ...

    @typing_extensions.final
    class ClusterTransfer(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPLID_FIELD_NUMBER: builtins.int
        USER_FIELD_NUMBER: builtins.int
        TRANSFERID_FIELD_NUMBER: builtins.int
        NEWCLUSTERID_FIELD_NUMBER: builtins.int
        NEWCONTINENTID_FIELD_NUMBER: builtins.int
        replId: builtins.str
        user: builtins.str
        transferId: builtins.str
        newClusterId: builtins.str
        newContinentId: builtins.str
        def __init__(
            self,
            *,
            replId: builtins.str = ...,
            user: builtins.str = ...,
            transferId: builtins.str = ...,
            newClusterId: builtins.str = ...,
            newContinentId: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["location", b"location", "newClusterId", b"newClusterId", "newContinentId", b"newContinentId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "newClusterId", b"newClusterId", "newContinentId", b"newContinentId", "replId", b"replId", "transferId", b"transferId", "user", b"user"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["location", b"location"]) -> typing_extensions.Literal["newClusterId", "newContinentId"] | None: ...

    @typing_extensions.final
    class SoftTakedown(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPLID_FIELD_NUMBER: builtins.int
        SOFTTAKEDOWNID_FIELD_NUMBER: builtins.int
        replId: builtins.str
        softTakedownId: builtins.str
        def __init__(
            self,
            *,
            replId: builtins.str = ...,
            softTakedownId: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["replId", b"replId", "softTakedownId", b"softTakedownId"]) -> None: ...

    @typing_extensions.final
    class Takedown(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPLID_FIELD_NUMBER: builtins.int
        replId: builtins.str
        def __init__(
            self,
            *,
            replId: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["replId", b"replId"]) -> None: ...

    @typing_extensions.final
    class GovalCommand(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UPDATEMETADATA_FIELD_NUMBER: builtins.int
        PARTIALUPDATEMETADATA_FIELD_NUMBER: builtins.int
        KILLREPL_FIELD_NUMBER: builtins.int
        UPDATESOURCEREPL_FIELD_NUMBER: builtins.int
        UPDATEREPLFLAGS_FIELD_NUMBER: builtins.int
        SOFTTAKEDOWN_FIELD_NUMBER: builtins.int
        TAKEDOWN_FIELD_NUMBER: builtins.int
        @property
        def updateMetadata(self) -> global___repl.Metadata: ...
        @property
        def partialUpdateMetadata(self) -> global___lore.PartialUpdateMetadata: ...
        @property
        def killRepl(self) -> global___lore.KillRepl: ...
        @property
        def updateSourceRepl(self) -> global___lore.UpdateSourceRepl: ...
        @property
        def updateReplFlags(self) -> global___lore.UpdateReplFlags: ...
        @property
        def softTakedown(self) -> global___lore.SoftTakedown: ...
        @property
        def takedown(self) -> global___lore.Takedown: ...
        def __init__(
            self,
            *,
            updateMetadata: global___repl.Metadata | None = ...,
            partialUpdateMetadata: global___lore.PartialUpdateMetadata | None = ...,
            killRepl: global___lore.KillRepl | None = ...,
            updateSourceRepl: global___lore.UpdateSourceRepl | None = ...,
            updateReplFlags: global___lore.UpdateReplFlags | None = ...,
            softTakedown: global___lore.SoftTakedown | None = ...,
            takedown: global___lore.Takedown | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["command", b"command", "killRepl", b"killRepl", "partialUpdateMetadata", b"partialUpdateMetadata", "softTakedown", b"softTakedown", "takedown", b"takedown", "updateMetadata", b"updateMetadata", "updateReplFlags", b"updateReplFlags", "updateSourceRepl", b"updateSourceRepl"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "killRepl", b"killRepl", "partialUpdateMetadata", b"partialUpdateMetadata", "softTakedown", b"softTakedown", "takedown", b"takedown", "updateMetadata", b"updateMetadata", "updateReplFlags", b"updateReplFlags", "updateSourceRepl", b"updateSourceRepl"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["command", b"command"]) -> typing_extensions.Literal["updateMetadata", "partialUpdateMetadata", "killRepl", "updateSourceRepl", "updateReplFlags", "softTakedown", "takedown"] | None: ...

    @typing_extensions.final
    class PartialUpdateMetadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FIELDMASK_FIELD_NUMBER: builtins.int
        UPDATEMETADATA_FIELD_NUMBER: builtins.int
        @property
        def fieldMask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
        @property
        def updateMetadata(self) -> global___repl.Metadata: ...
        def __init__(
            self,
            *,
            fieldMask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
            updateMetadata: global___repl.Metadata | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["fieldMask", b"fieldMask", "updateMetadata", b"updateMetadata"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["fieldMask", b"fieldMask", "updateMetadata", b"updateMetadata"]) -> None: ...

    @typing_extensions.final
    class MultiGovalCommand(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPLID_FIELD_NUMBER: builtins.int
        GOVALCOMMANDS_FIELD_NUMBER: builtins.int
        replId: builtins.str
        @property
        def govalCommands(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___lore.GovalCommand]: ...
        def __init__(
            self,
            *,
            replId: builtins.str = ...,
            govalCommands: collections.abc.Iterable[global___lore.GovalCommand] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["govalCommands", b"govalCommands", "replId", b"replId"]) -> None: ...

    @typing_extensions.final
    class KillRepl(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPLID_FIELD_NUMBER: builtins.int
        replId: builtins.str
        def __init__(
            self,
            *,
            replId: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["replId", b"replId"]) -> None: ...

    @typing_extensions.final
    class Restore(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPLID_FIELD_NUMBER: builtins.int
        RESTOREREPLID_FIELD_NUMBER: builtins.int
        replId: builtins.str
        restoreReplId: builtins.str
        def __init__(
            self,
            *,
            replId: builtins.str = ...,
            restoreReplId: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["replId", b"replId", "restoreReplId", b"restoreReplId"]) -> None: ...

    @typing_extensions.final
    class UpdateSourceRepl(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPLID_FIELD_NUMBER: builtins.int
        SOURCEREPLID_FIELD_NUMBER: builtins.int
        replId: builtins.str
        sourceReplId: builtins.str
        def __init__(
            self,
            *,
            replId: builtins.str = ...,
            sourceReplId: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["replId", b"replId", "sourceReplId", b"sourceReplId"]) -> None: ...

    @typing_extensions.final
    class UpdateReplFlags(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPLID_FIELD_NUMBER: builtins.int
        FLAGS_FIELD_NUMBER: builtins.int
        replId: builtins.str
        @property
        def flags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            replId: builtins.str = ...,
            flags: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["flags", b"flags", "replId", b"replId"]) -> None: ...

    def __init__(
        self,
    ) -> None: ...

global___lore = lore

@typing_extensions.final
class features(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Gpu(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing_extensions.final
    class Boosted(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing_extensions.final
    class Feature(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REQUIRED_FIELD_NUMBER: builtins.int
        GPU_FIELD_NUMBER: builtins.int
        BOOSTED_FIELD_NUMBER: builtins.int
        required: builtins.bool
        @property
        def gpu(self) -> global___features.Gpu: ...
        @property
        def boosted(self) -> global___features.Boosted: ...
        def __init__(
            self,
            *,
            required: builtins.bool = ...,
            gpu: global___features.Gpu | None = ...,
            boosted: global___features.Boosted | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["boosted", b"boosted", "feature", b"feature", "gpu", b"gpu"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["boosted", b"boosted", "feature", b"feature", "gpu", b"gpu", "required", b"required"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["feature", b"feature"]) -> typing_extensions.Literal["gpu", "boosted"] | None: ...

    def __init__(
        self,
    ) -> None: ...

global___features = features

@typing_extensions.final
class repl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[repl._Environment.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEVELOPMENT: repl._Environment.ValueType  # 0
        PRODUCTION: repl._Environment.ValueType  # 1

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    DEVELOPMENT: repl.Environment.ValueType  # 0
    PRODUCTION: repl.Environment.ValueType  # 1

    class _Persistence:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PersistenceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[repl._Persistence.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PERSISTENT: repl._Persistence.ValueType  # 0
        EPHEMERAL: repl._Persistence.ValueType  # 1
        NONE: repl._Persistence.ValueType  # 2
        READ_ONLY: repl._Persistence.ValueType  # 3

    class Persistence(_Persistence, metaclass=_PersistenceEnumTypeWrapper): ...
    PERSISTENT: repl.Persistence.ValueType  # 0
    EPHEMERAL: repl.Persistence.ValueType  # 1
    NONE: repl.Persistence.ValueType  # 2
    READ_ONLY: repl.Persistence.ValueType  # 3

    @typing_extensions.final
    class Buckets(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SNAPSHOTS_FIELD_NUMBER: builtins.int
        METADATA_FIELD_NUMBER: builtins.int
        snapshots: builtins.str
        metadata: builtins.str
        def __init__(
            self,
            *,
            snapshots: builtins.str = ...,
            metadata: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "snapshots", b"snapshots"]) -> None: ...

    @typing_extensions.final
    class Repl(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        LANGUAGE_FIELD_NUMBER: builtins.int
        BUCKET_FIELD_NUMBER: builtins.int
        SLUG_FIELD_NUMBER: builtins.int
        USER_FIELD_NUMBER: builtins.int
        SOURCEREPL_FIELD_NUMBER: builtins.int
        DATABASE_FIELD_NUMBER: builtins.int
        BUCKETS_FIELD_NUMBER: builtins.int
        USERID_FIELD_NUMBER: builtins.int
        id: builtins.str
        language: builtins.str
        bucket: builtins.str
        slug: builtins.str
        user: builtins.str
        sourceRepl: builtins.str
        database: builtins.str
        @property
        def buckets(self) -> global___repl.Buckets: ...
        @property
        def userId(self) -> global___repl.UserId: ...
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            language: builtins.str = ...,
            bucket: builtins.str = ...,
            slug: builtins.str = ...,
            user: builtins.str = ...,
            sourceRepl: builtins.str = ...,
            database: builtins.str = ...,
            buckets: global___repl.Buckets | None = ...,
            userId: global___repl.UserId | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["buckets", b"buckets", "userId", b"userId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "buckets", b"buckets", "database", b"database", "id", b"id", "language", b"language", "slug", b"slug", "sourceRepl", b"sourceRepl", "user", b"user", "userId", b"userId"]) -> None: ...

    @typing_extensions.final
    class UserId(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        ENVIRONMENT_FIELD_NUMBER: builtins.int
        id: builtins.int
        environment: global___repl.Environment.ValueType
        def __init__(
            self,
            *,
            id: builtins.int = ...,
            environment: global___repl.Environment.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment", "id", b"id"]) -> None: ...

    @typing_extensions.final
    class ResourceLimits(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Cachability:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _CachabilityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[repl.ResourceLimits._Cachability.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            NONE: repl.ResourceLimits._Cachability.ValueType  # 0
            USER: repl.ResourceLimits._Cachability.ValueType  # 1
            REPL: repl.ResourceLimits._Cachability.ValueType  # 2

        class Cachability(_Cachability, metaclass=_CachabilityEnumTypeWrapper): ...
        NONE: repl.ResourceLimits.Cachability.ValueType  # 0
        USER: repl.ResourceLimits.Cachability.ValueType  # 1
        REPL: repl.ResourceLimits.Cachability.ValueType  # 2

        NET_FIELD_NUMBER: builtins.int
        MEMORY_FIELD_NUMBER: builtins.int
        THREADS_FIELD_NUMBER: builtins.int
        SHARES_FIELD_NUMBER: builtins.int
        DISK_FIELD_NUMBER: builtins.int
        CACHE_FIELD_NUMBER: builtins.int
        RESTRICTNETWORK_FIELD_NUMBER: builtins.int
        PREVENTWAKEUP_FIELD_NUMBER: builtins.int
        net: builtins.bool
        memory: builtins.int
        threads: builtins.float
        shares: builtins.float
        disk: builtins.int
        cache: global___repl.ResourceLimits.Cachability.ValueType
        restrictNetwork: builtins.bool
        preventWakeup: builtins.bool
        def __init__(
            self,
            *,
            net: builtins.bool = ...,
            memory: builtins.int = ...,
            threads: builtins.float = ...,
            shares: builtins.float = ...,
            disk: builtins.int = ...,
            cache: global___repl.ResourceLimits.Cachability.ValueType = ...,
            restrictNetwork: builtins.bool = ...,
            preventWakeup: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["cache", b"cache", "disk", b"disk", "memory", b"memory", "net", b"net", "preventWakeup", b"preventWakeup", "restrictNetwork", b"restrictNetwork", "shares", b"shares", "threads", b"threads"]) -> None: ...

    @typing_extensions.final
    class Permissions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TOGGLEALWAYSON_FIELD_NUMBER: builtins.int
        toggleAlwaysOn: builtins.bool
        def __init__(
            self,
            *,
            toggleAlwaysOn: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["toggleAlwaysOn", b"toggleAlwaysOn"]) -> None: ...

    @typing_extensions.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPL_FIELD_NUMBER: builtins.int
        RESOURCELIMITS_FIELD_NUMBER: builtins.int
        INTERACTIVERESOURCELIMITS_FIELD_NUMBER: builtins.int
        PERSISTENCE_FIELD_NUMBER: builtins.int
        FLAGS_FIELD_NUMBER: builtins.int
        PERMISSIONS_FIELD_NUMBER: builtins.int
        FEATURES_FIELD_NUMBER: builtins.int
        BUILDINFO_FIELD_NUMBER: builtins.int
        @property
        def repl(self) -> global___repl.Repl: ...
        @property
        def resourceLimits(self) -> global___repl.ResourceLimits: ...
        @property
        def interactiveResourceLimits(self) -> global___repl.ResourceLimits: ...
        persistence: global___repl.Persistence.ValueType
        @property
        def flags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        @property
        def permissions(self) -> global___repl.Permissions: ...
        @property
        def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___features.Feature]: ...
        @property
        def buildInfo(self) -> global___repl.BuildInfo: ...
        def __init__(
            self,
            *,
            repl: global___repl.Repl | None = ...,
            resourceLimits: global___repl.ResourceLimits | None = ...,
            interactiveResourceLimits: global___repl.ResourceLimits | None = ...,
            persistence: global___repl.Persistence.ValueType = ...,
            flags: collections.abc.Iterable[builtins.str] | None = ...,
            permissions: global___repl.Permissions | None = ...,
            features: collections.abc.Iterable[global___features.Feature] | None = ...,
            buildInfo: global___repl.BuildInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["buildInfo", b"buildInfo", "interactiveResourceLimits", b"interactiveResourceLimits", "permissions", b"permissions", "repl", b"repl", "resourceLimits", b"resourceLimits"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["buildInfo", b"buildInfo", "features", b"features", "flags", b"flags", "interactiveResourceLimits", b"interactiveResourceLimits", "permissions", b"permissions", "persistence", b"persistence", "repl", b"repl", "resourceLimits", b"resourceLimits"]) -> None: ...

    @typing_extensions.final
    class BuildInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DEPLOYMENTID_FIELD_NUMBER: builtins.int
        URL_FIELD_NUMBER: builtins.int
        BUILDID_FIELD_NUMBER: builtins.int
        MACHINETIER_FIELD_NUMBER: builtins.int
        deploymentId: builtins.str
        url: builtins.str
        buildId: builtins.str
        machineTier: builtins.str
        def __init__(
            self,
            *,
            deploymentId: builtins.str = ...,
            url: builtins.str = ...,
            buildId: builtins.str = ...,
            machineTier: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["buildId", b"buildId", "deploymentId", b"deploymentId", "machineTier", b"machineTier", "url", b"url"]) -> None: ...

    def __init__(
        self,
    ) -> None: ...

global___repl = repl

@typing_extensions.final
class PrivateReplsPowerup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___PrivateReplsPowerup = PrivateReplsPowerup

@typing_extensions.final
class GhostwriterPowerup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___GhostwriterPowerup = GhostwriterPowerup

@typing_extensions.final
class ConnectivityPowerup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ConnectivityPowerup = ConnectivityPowerup

@typing_extensions.final
class PowerUp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRESAT_FIELD_NUMBER: builtins.int
    PRIVATE_FIELD_NUMBER: builtins.int
    GHOSTWRITER_FIELD_NUMBER: builtins.int
    CONNECTIVITY_FIELD_NUMBER: builtins.int
    @property
    def expiresAt(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def private(self) -> global___PrivateReplsPowerup: ...
    @property
    def ghostwriter(self) -> global___GhostwriterPowerup: ...
    @property
    def connectivity(self) -> global___ConnectivityPowerup: ...
    def __init__(
        self,
        *,
        expiresAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        private: global___PrivateReplsPowerup | None = ...,
        ghostwriter: global___GhostwriterPowerup | None = ...,
        connectivity: global___ConnectivityPowerup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connectivity", b"connectivity", "expiresAt", b"expiresAt", "ghostwriter", b"ghostwriter", "powerup", b"powerup", "private", b"private"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connectivity", b"connectivity", "expiresAt", b"expiresAt", "ghostwriter", b"ghostwriter", "powerup", b"powerup", "private", b"private"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["powerup", b"powerup"]) -> typing_extensions.Literal["private", "ghostwriter", "connectivity"] | None: ...

global___PowerUp = PowerUp

@typing_extensions.final
class UserPowerUps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    POWERUPS_FIELD_NUMBER: builtins.int
    userId: builtins.int
    username: builtins.str
    @property
    def powerups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PowerUp]: ...
    def __init__(
        self,
        *,
        userId: builtins.int = ...,
        username: builtins.str = ...,
        powerups: collections.abc.Iterable[global___PowerUp] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["powerups", b"powerups", "userId", b"userId", "username", b"username"]) -> None: ...

global___UserPowerUps = UserPowerUps
